#!/usr/bin/env python3
"""
IDE配置管理模块的单元测试
"""

import unittest
import tempfile
import json
import os
import shutil
from pathlib import Path

# 添加src-min到路径
import sys
sys.path.insert(0, os.path.join(os.path.dirname(__file__), '..', 'src-min'))

from config.ide_config import IDEConfig


class TestIDEConfig(unittest.TestCase):
    """测试IDE配置类"""
    
    def setUp(self):
        """测试前的准备工作"""
        # 创建临时目录用于测试
        self.temp_dir = tempfile.mkdtemp()
        self.config_dir = Path(self.temp_dir) / '.interactive_feedback_mcp_test'
        
        # 创建测试用的IDEConfig实例
        self.config = IDEConfig()
        self.config.config_dir = self.config_dir
        self.config.config_file = self.config_dir / 'ide_config.json'
        
        # 确保配置目录存在
        self.config_dir.mkdir(exist_ok=True)
    
    def tearDown(self):
        """测试后的清理工作"""
        # 清理临时目录
        if os.path.exists(self.temp_dir):
            shutil.rmtree(self.temp_dir)
    
    def test_default_config(self):
        """测试默认配置"""
        self.assertEqual(self.config.current_ide, "cursor")
        self.assertIn("cursor", self.config.supported_ides)
        self.assertIn("kiro", self.config.supported_ides)
        self.assertIn("vscode", self.config.supported_ides)
    
    def test_get_current_ide(self):
        """测试获取当前IDE"""
        current_ide = self.config.get_current_ide()
        self.assertEqual(current_ide['name'], "cursor")
        self.assertEqual(current_ide['display_name'], "Cursor")
        self.assertEqual(current_ide['command'], "cursor")
    
    def test_get_supported_ides(self):
        """测试获取支持的IDE列表"""
        ides = self.config.get_supported_ides()
        self.assertIsInstance(ides, dict)
        self.assertIn("cursor", ides)
        self.assertIn("kiro", ides)
        self.assertIn("vscode", ides)
        
        # 检查每个IDE的信息结构
        for ide_key, ide_info in ides.items():
            self.assertIn('name', ide_info)
            self.assertIn('display_name', ide_info)
            self.assertIn('command', ide_info)
            self.assertIn('description', ide_info)
            self.assertIn('available', ide_info)
            self.assertIn('current', ide_info)
    
    def test_save_and_load_config(self):
        """测试保存和加载配置"""
        # 保存配置
        success = self.config.save_config("vscode")
        self.assertTrue(success)
        
        # 验证配置文件存在
        self.assertTrue(self.config.config_file.exists())
        
        # 重新加载配置
        loaded_ide = self.config.load_config()
        self.assertEqual(loaded_ide, "vscode")
        self.assertEqual(self.config.current_ide, "vscode")
    
    def test_invalid_ide_name(self):
        """测试无效的IDE名称"""
        success = self.config.save_config("invalid_ide")
        self.assertFalse(success)
    
    def test_is_ide_available(self):
        """测试IDE可用性检查"""
        # 测试已知命令的可用性
        self.assertIsInstance(self.config.is_ide_available("cursor"), bool)
        self.assertIsInstance(self.config.is_ide_available("kiro"), bool)
        self.assertIsInstance(self.config.is_ide_available("vscode"), bool)
        
        # 测试无效IDE
        self.assertFalse(self.config.is_ide_available("invalid_ide"))
    
    def test_config_file_corruption(self):
        """测试配置文件损坏处理"""
        # 创建损坏的配置文件
        with open(self.config.config_file, 'w') as f:
            f.write("invalid json content")
        
        # 加载配置应该回退到默认值
        loaded_ide = self.config.load_config()
        self.assertEqual(loaded_ide, "cursor")
    
    def test_reset_to_default(self):
        """测试重置为默认配置"""
        # 先保存一个非默认配置
        self.config.save_config("vscode")
        self.assertEqual(self.config.current_ide, "vscode")
        
        # 重置为默认
        success = self.config.reset_to_default()
        self.assertTrue(success)
        self.assertEqual(self.config.current_ide, "cursor")


class TestIDEUtils(unittest.TestCase):
    """测试IDE工具函数"""
    
    def test_get_ide_command(self):
        """测试获取IDE命令"""
        from ide_utils import get_ide_command
        
        self.assertEqual(get_ide_command("cursor"), "cursor")
        self.assertEqual(get_ide_command("kiro"), "kiro")
        self.assertEqual(get_ide_command("vscode"), "code")
        self.assertEqual(get_ide_command("invalid"), "cursor")  # 默认值
    
    def test_is_ide_available(self):
        """测试IDE可用性检查"""
        from ide_utils import is_ide_available
        
        # 测试已知IDE的可用性
        self.assertIsInstance(is_ide_available("cursor"), bool)
        self.assertIsInstance(is_ide_available("vscode"), bool)
        
        # 测试无效IDE
        self.assertFalse(is_ide_available("invalid_ide"))
    
    def test_get_ide_info(self):
        """测试获取IDE信息"""
        from ide_utils import get_ide_info
        
        info = get_ide_info("cursor")
        self.assertIsInstance(info, dict)
        self.assertIn('name', info)
        self.assertIn('command', info)
        self.assertIn('description', info)
        self.assertIn('available', info)


if __name__ == '__main__':
    unittest.main()


"""
选项卡基础类

定义所有选项卡的通用接口和行为。
"""

from abc import ABC, abstractmethod, ABCMeta
from PySide6.QtWidgets import QWidget
from PySide6.QtCore import QObject


class BaseTabMeta(type(QWidget), ABCMeta):
    """解决QWidget和ABC的元类冲突"""
    pass


class BaseTab(QWidget, ABC, metaclass=BaseTabMeta):
    """选项卡基础类
    
    所有选项卡都应该继承此类，并实现_setup_ui方法。
    """
    
    def __init__(self, parent=None):
        super().__init__(parent)
        self._setup_ui()
    
    @abstractmethod
    def _setup_ui(self):
        """子类必须实现的UI创建方法"""
        pass
    
    def refresh_data(self):
        """刷新数据的通用方法，子类可以重写"""
        pass 


#!/usr/bin/env python3
"""
Stop Hook处理脚本
智能处理stop事件，避免死循环
"""
import sys
import json
import os
from pathlib import Path

# 添加当前目录到Python路径
current_dir = Path(__file__).parent
sys.path.insert(0, str(current_dir))

from session_manager import SessionManager
from context_formatter import format_for_stop_hook


def main():
    """主函数"""
    try:
        # 从stdin读取JSON输入
        input_data = json.load(sys.stdin)

        # 提取关键信息
        session_id = input_data.get('session_id', '')
        stop_hook_active = input_data.get('stop_hook_active', False)

        # 创建会话管理器
        manager = SessionManager()

        # 决策逻辑
        if session_id:
            # 1. 检查用户是否点击关闭按钮
            if manager.is_user_closed_by_button(session_id):
                # 用户主动点击关闭，完全不提示（静默允许停止）
                return 0

            # 2. 检查是否超时关闭
            if manager.is_timeout_closed(session_id):
                # 超时关闭场景，最多提示2次
                current_block_count = manager.get_block_count(session_id)
                MAX_BLOCK_COUNT = 2

                if current_block_count >= MAX_BLOCK_COUNT:
                    # 超过最大阻止次数，允许停止以避免死循环
                    manager.clear_session(session_id)
                    return 0

                # 未超过2次，继续提示并增加计数
                manager.increment_block_count(session_id)
            else:
                # 3. 正常场景（非关闭状态），重置计数
                # 这样每次正常的stop hook都会重新开始计数
                if manager.get_block_count(session_id) > 0:
                    manager.clear_session(session_id)

        # 4. 默认行为：阻止停止并提示使用feedback工具
        # 使用新的格式化上下文信息
        if session_id:
            # 获取项目路径
            project_path = os.getcwd()
            reason_text = format_for_stop_hook(session_id, project_path)
        else:
            reason_text = "请你调用 feedback mcp tool 向用户反馈/请示。示例：使用 mcp__feedback__feedback 工具向用户汇报当前工作进度、完成状态或请求下一步指示。"

        result = {
            "decision": "block",
            "reason": reason_text
        }
        print(json.dumps(result, ensure_ascii=False))
        return 0
        
    except Exception as e:
        # 发生错误时，默认允许停止（避免卡死）
        error_result = {
            "decision": "approve",
            "reason": f"Hook处理出错: {str(e)}"
        }
        print(json.dumps(error_result, ensure_ascii=False), file=sys.stderr)
        return 1

if __name__ == "__main__":
    sys.exit(main())


"""
聊天标签页 - 包含反馈输入、预定义选项、指令管理等功能
"""
import sys
import os
import json
from datetime import datetime
from typing import Optional, List, Dict
from PySide6.QtWidgets import (
    QWidget, QVBoxLayout, QHBoxLayout, QFrame, QGridLayout,
    QCheckBox, QPushButton, QProgressBar, QSizePolicy, QFileDialog, QMessageBox, QLabel
)
from PySide6.QtCore import Qt, Signal, QTimer, QPoint
from PySide6.QtGui import QFont, QTextCursor

try:
    from .base_tab import BaseTab
except ImportError:
    from base_tab import BaseTab

try:
    from ..components.feedback_text_edit import FeedbackTextEdit
    from ..components.markdown_display import MarkdownDisplayWidget
except ImportError:
    try:
        from components.feedback_text_edit import FeedbackTextEdit
        from components.markdown_display import MarkdownDisplayWidget
    except ImportError:
        # 如果导入失败，使用原始组件
        from PySide6.QtWidgets import QTextEdit
        FeedbackTextEdit = QTextEdit
        MarkdownDisplayWidget = QTextEdit

# 导入指令管理组件
try:
    from ..components.command_tab import CommandTabWidget
except ImportError:
    try:
        from components.command_tab import CommandTabWidget
    except ImportError:
        CommandTabWidget = None

# 导入历史记录弹窗组件
try:
    from ..components.history_popup import HistoryPopup
    HISTORY_POPUP_AVAILABLE = True
except ImportError:
    try:
        from components.history_popup import HistoryPopup
        HISTORY_POPUP_AVAILABLE = True
    except ImportError:
        HISTORY_POPUP_AVAILABLE = False
        print("Warning: HistoryPopup component not available")


class ChatTab(BaseTab):
    """聊天标签页 - 处理用户反馈输入和交互"""
    
    # 信号定义
    feedback_submitted = Signal(list, list)  # 结构化内容数组, 图片列表
    command_executed = Signal(str)  # 指令内容
    option_executed = Signal(int)  # 选项索引
    text_changed = Signal()  # 文本变化
    
    def __init__(self, prompt: str, predefined_options: Optional[List[str]] = None,
                 project_path: Optional[str] = None, work_title: Optional[str] = None,
                 timeout: int = 60, files: Optional[List[str]] = None, bugdetail: Optional[str] = None,
                 session_id: Optional[str] = None, workspace_id: Optional[str] = None, parent=None):
        super().__init__(parent)
        self.prompt = prompt
        self.predefined_options = predefined_options or []
        self.project_path = project_path
        self.work_title = work_title or ""
        self.timeout = timeout
        self.elapsed_time = 0
        self.files = files or []  # 保存文件列表
        self.bugdetail = bugdetail  # 保存bug详情
        self.session_id = session_id  # 保存会话ID
        self.workspace_id = workspace_id  # 保存工作空间ID

        # 阶段信息
        self.stage_info = None
        self._load_stage_info()

        # 工作空间信息
        self.workspace_goal = None
        self.dialog_title = None
        self._load_workspace_context()

        # 任务信息
        self.current_task = None
        self.next_task = None
        self._load_task_info()

        # 深度思考模式状态 - 从设置中恢复
        self.deep_thinking_mode = self._load_deep_thinking_mode()

        # UI组件
        self.description_display = None
        self.option_checkboxes = []
        self.command_widget = None
        self.feedback_text = None
        self.submit_button = None
        self.progress_bar = None
        self.image_button = None  # 图片选择按钮
        self.history_button = None  # 历史记录按钮
        self.deep_thinking_button = None  # 深度思考按钮

        # 指令标签相关属性
        self.selected_command = None  # 当前选中的指令信息
        self.command_label_widget = None  # 指令标签组件

        self.create_ui()

        # 初始化完成后更新深度思考按钮状态
        if hasattr(self, 'deep_thinking_button') and self.deep_thinking_button:
            self.deep_thinking_button.setChecked(self.deep_thinking_mode)

        # 保存AI发送的消息（prompt）到历史记录
        if prompt and prompt.strip():
            self.save_response_to_history(prompt)
    
    def create_ui(self):
        """创建聊天标签页UI"""
        layout = QVBoxLayout(self)

        # 显示当前任务（如果有）
        if self.current_task:
            self._create_current_task_label(layout)

        # 构建display_prompt
        display_prompt = self.prompt

        # 1. 如果有bugdetail，添加到前面
        if self.bugdetail:
            display_prompt = f"🐛 **当前正在修复bug:**\n{self.bugdetail}\n\n---\n\n{display_prompt}"

        # 2. 如果有上下文信息，添加到最前面
        context_info = self._format_context_info()
        if context_info:
            display_prompt = f"{context_info}{display_prompt}"

        # 使用支持Markdown的显示组件 - 简化布局，去掉外围框架
        self.description_display = MarkdownDisplayWidget()
        self.description_display.setMarkdownText(display_prompt)
        # 设置合适的高度，默认250px，最大400px
        self.description_display.setMinimumHeight(250)
        self.description_display.setMaximumHeight(400)
        layout.addWidget(self.description_display)
        
        # 创建一个反馈布局容器（只包含其他元素，不包含markdown显示）
        feedback_container = QWidget()
        feedback_layout = QVBoxLayout(feedback_container)
        feedback_layout.setContentsMargins(5, 5, 5, 5)

        # 添加预定义选项
        if self.predefined_options:
            self._create_predefined_options(feedback_layout)

        # 添加阶段切换按钮（如果有）
        if self.stage_info:
            self._create_stage_buttons(feedback_layout)

        # 添加下一任务按钮（独立显示，不依赖stage_info）
        if self.next_task:
            self._create_next_task_button(feedback_layout)

        # 添加文件列表显示
        if self.files:
            self._create_files_list(feedback_layout)

        # 使用新的指令管理组件（隐藏固定显示区域）
        if CommandTabWidget:
            self.command_widget = CommandTabWidget(self.project_path, self)
            self.command_widget.command_executed.connect(self._handle_command_execution)
            # 隐藏固定显示的指令区域，用户通过 / // /// 弹窗使用指令
            self.command_widget.hide()

        # 自由文本反馈输入
        self._create_feedback_input(feedback_layout)
        
        # 提交按钮布局
        self._create_submit_section(feedback_layout)
        
        # 进度条布局
        if self.timeout > 0:
            self._create_progress_section(feedback_layout)

        # 添加反馈容器到主布局
        layout.addWidget(feedback_container)

    def _format_context_info(self) -> str:
        """格式化上下文信息为Markdown文本

        Returns:
            str: 格式化的Markdown文本,如果所有信息都为空则返回空字符串

        Example:
            "📦 工作空间: XXX\n📍 阶段: XXX\n💬 对话: XXX\n\n---\n\n"
        """
        parts = []

        if self.workspace_goal:
            parts.append(f"📦 工作空间: {self.workspace_goal}")

        if self.stage_info and self.stage_info.get('current_stage'):
            stage_name = self.stage_info['current_stage'].get('title', '')
            parts.append(f"📍 阶段: {stage_name}")

        if self.dialog_title:
            parts.append(f"💬 对话: {self.dialog_title}")

        if not parts:
            return ""

        return "\n".join(parts) + "\n\n---\n\n"

    def _create_files_list(self, layout):
        """创建文件列表显示区域"""
        import subprocess
        import platform
        from functools import partial

        # 创建紧凑的文件列表容器（使用水平布局）
        files_container = QWidget()
        files_container.setMaximumHeight(40)  # 限制高度，更紧凑
        files_container_layout = QHBoxLayout(files_container)
        files_container_layout.setContentsMargins(5, 5, 5, 5)
        files_container_layout.setSpacing(10)

        # 添加文件图标标题
        title_label = QLabel("📝")
        title_label.setToolTip("AI创建或修改的文件")
        title_label.setStyleSheet("""
            QLabel {
                font-size: 14px;
                color: #888;
                background-color: transparent;
            }
        """)
        files_container_layout.addWidget(title_label)

        # 为每个文件创建紧凑的可点击标签
        for file_path in self.files:
            file_name = os.path.basename(file_path)
            # 如果文件名太长，截断显示
            display_name = file_name if len(file_name) <= 20 else file_name[:17] + "..."

            file_btn = QPushButton(display_name)
            # 获取IDE名称
            ide_name = os.getenv('IDE', 'cursor')
            # IDE显示名称映射
            ide_display_names = {
                'cursor': 'Cursor',
                'kiro': 'Kiro',
                'vscode': 'VSCode',
                'code': 'VSCode'
            }
            display_ide = ide_display_names.get(ide_name.lower(), ide_name)
            file_btn.setToolTip(f"点击在{display_ide}中打开: {file_path}")
            file_btn.setCursor(Qt.PointingHandCursor)  # 设置手形光标
            file_btn.setStyleSheet("""
                QPushButton {
                    background-color: rgba(76, 175, 80, 20);
                    color: #4CAF50;
                    border: 1px solid rgba(76, 175, 80, 40);
                    padding: 3px 8px;
                    border-radius: 3px;
                    font-size: 11px;
                    font-weight: 500;
                }
                QPushButton:hover {
                    background-color: rgba(76, 175, 80, 40);
                    border: 1px solid #4CAF50;
                }
                QPushButton:pressed {
                    background-color: rgba(76, 175, 80, 60);
                }
            """)

            # 使用partial函数绑定参数，避免闭包问题
            def open_with_ide(file_path):
                try:
                    # 导入ide_utils模块
                    import sys
                    parent_dir = os.path.dirname(os.path.dirname(os.path.abspath(__file__)))
                    if parent_dir not in sys.path:
                        sys.path.insert(0, parent_dir)
                    from ide_utils import open_project_with_ide

                    # 获取IDE名称
                    ide_name = os.getenv('IDE', 'cursor')

                    # 使用通用的IDE打开函数
                    success = open_project_with_ide(file_path, ide_name)

                    if not success:
                        # 如果失败，使用系统默认编辑器打开
                        if platform.system() == "Darwin":
                            subprocess.run(["open", file_path], check=True)
                        elif platform.system() == "Windows":
                            os.startfile(file_path)
                        else:
                            subprocess.run(["xdg-open", file_path], check=True)

                except Exception as e:
                    # 使用系统默认编辑器打开作为最终后备
                    try:
                        if platform.system() == "Darwin":
                            subprocess.run(["open", file_path], check=True)
                        elif platform.system() == "Windows":
                            os.startfile(file_path)
                        else:
                            subprocess.run(["xdg-open", file_path], check=True)
                    except Exception as e2:
                        QMessageBox.warning(self, "打开失败",
                            f"无法打开文件: {file_name}\n"
                            f"路径: {file_path}\n"
                            f"错误: {str(e2)}")

            file_btn.clicked.connect(partial(open_with_ide, file_path))
            files_container_layout.addWidget(file_btn)

        # 添加弹簧使按钮靠左对齐
        files_container_layout.addStretch()

        layout.addWidget(files_container)
    
    def _create_predefined_options(self, layout):
        """创建预定义选项区域 - 与原始版本样式保持一致"""
        options_frame = QFrame()
        options_frame.setMinimumHeight(100)  # 设置可选项区域最小高度为100
        # 使用网格布局实现两列显示，与原版保持一致
        options_layout = QGridLayout(options_frame)
        options_layout.setContentsMargins(0, 10, 0, 10)
        options_layout.setSpacing(5)  # 设置间距
        
        # 计算网格的行列布局
        total_options = len(self.predefined_options)
        columns = 2  # 两列布局
        rows = (total_options + columns - 1) // columns  # 向上取整
        
        for i, option in enumerate(self.predefined_options):
            # 计算当前项目在网格中的位置
            row = i // columns
            col = i % columns
            
            # Create horizontal layout for each option (checkbox + button)
            option_item_frame = QFrame()
            option_item_layout = QHBoxLayout(option_item_frame)
            option_item_layout.setContentsMargins(5, 2, 5, 2)
            
            # Checkbox
            checkbox = QCheckBox(option)
            self.option_checkboxes.append(checkbox)
            option_item_layout.addWidget(checkbox)
            
            # Add stretch to push button to the right
            option_item_layout.addStretch()
            
            # Execute button for this option - 使用与原始版本相同的样式
            execute_btn = QPushButton("立即执行")
            execute_btn.setMaximumWidth(80)
            execute_btn.setProperty('option_index', i)
            execute_btn.clicked.connect(lambda checked, idx=i: self._execute_option_immediately(idx))
            execute_btn.setStyleSheet("""
                QPushButton {
                    background-color: #FF9800;
                    color: white;
                    border: none;
                    padding: 4px 8px;
                    border-radius: 3px;
                    font-size: 11px;
                }
                QPushButton:hover {
                    background-color: #F57C00;
                }
                QPushButton:pressed {
                    background-color: #E65100;
                }
            """)
            option_item_layout.addWidget(execute_btn)
            
            # Add frame to grid layout
            options_layout.addWidget(option_item_frame, row, col)
        
        layout.addWidget(options_frame)
    
    def _create_feedback_input(self, layout):
        """创建反馈输入区域"""
        # 创建指令标签区域（默认隐藏）
        self._create_command_label_section(layout)
        
        self.feedback_text = FeedbackTextEdit()
        
        # 设置项目路径，启用指令弹窗功能
        if self.project_path:
            self.feedback_text.set_project_path(self.project_path)
        
        # 设置自定义指令选择处理器
        self.feedback_text.set_command_handler(self._on_command_selected_new)
        
        # 设置输入框的大小策略，让它能够随窗口拉伸自适应高度
        self.feedback_text.setSizePolicy(QSizePolicy.Expanding, QSizePolicy.Expanding)
        
        font_metrics = self.feedback_text.fontMetrics()
        row_height = font_metrics.height()
        # Calculate height for 5 lines + some padding for margins
        padding = self.feedback_text.contentsMargins().top() + self.feedback_text.contentsMargins().bottom() + 5
        self.feedback_text.setMinimumHeight(5 * row_height + padding)

        self.feedback_text.setPlaceholderText("请在此输入您的反馈内容 (Ctrl+Enter 或 Cmd+Enter，输入/打开项目指令; 输入//打开个人指令；输入///打开系统指令；输入指令对应的字母选中指令)")
        
        # 监听文本变化，动态改变发送按钮颜色
        self.feedback_text.textChanged.connect(self._on_text_changed)
        
        layout.addWidget(self.feedback_text)
    
    def _create_command_label_section(self, layout):
        """创建紧凑型Element UI Tag风格的指令标签区域"""
        self.command_label_widget = QFrame()
        # 默认样式，会在显示时根据类型动态设置
        self.command_label_widget.setStyleSheet("""
            QFrame {
                background: #409EFF;
                border: 1px solid #409EFF;
                border-radius: 4px;
                margin: 2px 0px;
                padding: 0px;
            }
        """)
        self.command_label_widget.hide()  # 默认隐藏
        
        label_layout = QHBoxLayout(self.command_label_widget)
        label_layout.setContentsMargins(6, 4, 6, 4)
        label_layout.setSpacing(6)
        
        # 关闭按钮 - 在容器内左侧
        close_button = QPushButton("×")
        close_button.setFixedSize(16, 16)
        close_button.setToolTip("清除选中的指令 (或按ESC键)")
        close_button.setStyleSheet("""
            QPushButton {
                background: transparent;
                color: rgba(255, 255, 255, 0.8);
                border: none;
                border-radius: 8px;
                font-size: 12px;
                font-weight: bold;
            }
            QPushButton:hover {
                background: rgba(255, 255, 255, 0.2);
                color: white;
            }
            QPushButton:pressed {
                background: rgba(255, 255, 255, 0.3);
            }
        """)
        close_button.clicked.connect(self._clear_selected_command)
        label_layout.addWidget(close_button)
        
        # 指令标题标签
        self.command_title_label = QLabel()
        self.command_title_label.setStyleSheet("""
            QLabel {
                color: white; 
                font-weight: 500;
                font-size: 12px;
                background: transparent;
                border: none;
                padding: 0px;
            }
        """)
        label_layout.addWidget(self.command_title_label)
        
        # 编辑按钮 - 小图标
        edit_button = QPushButton("✏️")
        edit_button.setFixedSize(16, 16)
        edit_button.setToolTip("在IDE中打开指令文件")
        edit_button.setStyleSheet("""
            QPushButton {
                background: transparent;
                color: rgba(255, 255, 255, 0.8);
                border: none;
                border-radius: 8px;
                font-size: 10px;
                font-weight: bold;
            }
            QPushButton:hover {
                background: rgba(255, 255, 255, 0.2);
                color: white;
            }
            QPushButton:pressed {
                background: rgba(255, 255, 255, 0.3);
            }
        """)
        edit_button.clicked.connect(self._edit_selected_command)
        label_layout.addWidget(edit_button)
        
        layout.addWidget(self.command_label_widget)
    
    def _on_command_selected_new(self, command_content: str, command_data: dict = None):
        """新的指令选择处理方法 - 显示标签而不是替换文本"""
        # 使用直接传递的指令数据，避免通过弹窗获取可能不准确的数据
        if command_data:
            self.selected_command = {
                'title': command_data.get('title', '未知指令'),
                'content': command_content,
                'type': command_data.get('type', 'unknown'),
                'full_path': command_data.get('full_path', '')  # 保存文件路径
            }
            self._show_command_label()

        # 关闭弹窗但不修改输入框内容
        self.feedback_text._close_command_popup()
    
    def _show_command_label(self):
        """显示紧凑型Element UI Tag风格的指令标签"""
        if not self.selected_command:
            return
            
        # Element UI Tag的类型配色
        type_config = {
            'project': {
                'bg_color': '#409EFF',
                'border_color': '#409EFF'
            },
            'personal': {
                'bg_color': '#67C23A', 
                'border_color': '#67C23A'
            },
            'system': {
                'bg_color': '#E6A23C',
                'border_color': '#E6A23C'
            }
        }
        
        config = type_config.get(self.selected_command['type'], {
            'bg_color': '#909399',
            'border_color': '#909399'
        })
        
        # 更新整个容器的Element UI Tag样式
        self.command_label_widget.setStyleSheet(f"""
            QFrame {{
                background: {config['bg_color']};
                border: 1px solid {config['border_color']};
                border-radius: 4px;
                margin: 2px 0px;
                padding: 0px;
            }}
        """)
        
        # 设置标题
        self.command_title_label.setText(self.selected_command['title'])
        
        # 显示标签
        self.command_label_widget.show()
    
    def _clear_selected_command(self):
        """清除选中的指令"""
        self.selected_command = None
        self.command_label_widget.hide()
    
    def _select_image(self):
        """选择图片文件"""
        try:
            file_dialog = QFileDialog(self)
            file_dialog.setFileMode(QFileDialog.ExistingFiles)  # 允许选择多个文件
            file_dialog.setNameFilter("图片文件 (*.png *.jpg *.jpeg *.gif *.bmp *.webp);;所有文件 (*)")
            file_dialog.setWindowTitle("选择图片文件")
            
            if file_dialog.exec():
                selected_files = file_dialog.selectedFiles()
                
                for file_path in selected_files:
                    # 检查文件大小
                    try:
                        import os
                        file_size = os.path.getsize(file_path)
                        file_size_mb = file_size / (1024 * 1024)
                        
                        if file_size_mb > 50:  # 限制原始文件大小不超过50MB
                            QMessageBox.warning(
                                self, 
                                "文件过大", 
                                f"文件 {os.path.basename(file_path)} 大小为 {file_size_mb:.1f}MB，超过50MB限制。\n"
                                "请选择更小的图片文件。"
                            )
                            continue
                        
                        # 添加图片到编辑器
                        self.feedback_text.add_image_file(file_path)
                        
                    except Exception as e:
                        QMessageBox.warning(
                            self, 
                            "添加图片失败", 
                            f"无法添加图片 {file_path}: {str(e)}"
                        )
                        
        except Exception as e:
            QMessageBox.critical(
                self, 
                "选择图片失败", 
                f"选择图片时发生错误: {str(e)}"
            )
    
    def _create_submit_section(self, layout):
        """创建提交按钮区域"""
        submit_layout = QHBoxLayout()
        
        # 深度思考按钮 - 放在最左边
        self.deep_thinking_button = QPushButton("🧠")
        self.deep_thinking_button.setToolTip("深度思考模式")
        self.deep_thinking_button.setCheckable(True)  # 可切换状态
        self.deep_thinking_button.setChecked(self.deep_thinking_mode)
        self.deep_thinking_button.clicked.connect(self._toggle_deep_thinking)
        self.deep_thinking_button.setMaximumWidth(30)
        self.deep_thinking_button.setObjectName("deep_thinking_btn")
        self.deep_thinking_button.setStyleSheet("""
            QPushButton#deep_thinking_btn {
                background-color: #404040;
                color: white;
                border: 1px solid #555;
                height: 30px;
                width: 30px;
                line-height: 30px;
                text-align: center;
                border-radius: 4px;
                font-size: 18px;
                font-weight: bold;
            }
            QPushButton#deep_thinking_btn:checked {
                background: qlineargradient(x1:0, y1:0, x2:1, y2:1,
                    stop:0 #667eea, stop:1 #764ba2);
                border: 2px solid #667eea;
            }
            QPushButton#deep_thinking_btn:hover {
                background-color: #505050;
            }
            QPushButton#deep_thinking_btn:checked:hover {
                background: qlineargradient(x1:0, y1:0, x2:1, y2:1,
                    stop:0 #7788ff, stop:1 #8755b2);
            }
            QPushButton#deep_thinking_btn:pressed {
                background-color: #303030;
            }
        """)
        submit_layout.addWidget(self.deep_thinking_button)
        
        # 添加一些间距
        submit_layout.addSpacing(5)
        
        # 指令按钮 - 快速打开指令弹层
        self.command_button = QPushButton("⚡")
        self.command_button.setToolTip("打开指令列表 (相当于输入 / 触发)")
        self.command_button.clicked.connect(self._show_command_popup)
        self.command_button.setMaximumWidth(30)
        self.command_button.setStyleSheet("""
            QPushButton {
                background-color: #666666;
                color: white;
                border: none;
                height:30px;
                width:30px;
                line-height:30px;
                text-align:center;
                border-radius: 4px;
                font-size: 18px;
                font-weight: bold;
            }
            QPushButton:hover {
                background-color: #777777;
            }
            QPushButton:pressed {
                background-color: #555555;
            }
        """)
        submit_layout.addWidget(self.command_button)
        
        # 添加一些间距
        submit_layout.addSpacing(5)
        
        # 图片选择按钮 - 只保留图标，与发送按钮并排
        self.image_button = QPushButton("📷")
        self.image_button.setToolTip("选择图片文件 (支持 PNG、JPG、JPEG、GIF、BMP、WebP)")
        self.image_button.clicked.connect(self._select_image)
        # 设置最小宽度，让高度自动匹配发送按钮
        self.image_button.setMaximumWidth(30)
        self.image_button.setStyleSheet("""
            QPushButton {
                background-color: #666666;
                color: white;
                border: none;
                height:30px;
                width:30px;
                line-height:30px;
                text-align:center;
                border-radius: 4px;
                font-size: 18px;
                font-weight: bold;
            }
            QPushButton:hover {
                background-color: #777777;
            }
            QPushButton:pressed {
                background-color: #555555;
            }
        """)
        submit_layout.addWidget(self.image_button)
        
        # 添加一些间距
        submit_layout.addSpacing(5)
        
        # 历史记录按钮
        self.history_button = QPushButton("📝")
        self.history_button.setToolTip("查看历史记录 (最近10条)")
        self.history_button.clicked.connect(self._show_history)
        self.history_button.setMaximumWidth(30)
        self.history_button.setStyleSheet("""
            QPushButton {
                background-color: #666666;
                color: white;
                border: none;
                height:30px;
                width:30px;
                line-height:30px;
                text-align:center;
                border-radius: 4px;
                font-size: 18px;
                font-weight: bold;
            }
            QPushButton:hover {
                background-color: #777777;
            }
            QPushButton:pressed {
                background-color: #555555;
            }
        """)
        submit_layout.addWidget(self.history_button)
        
        # 添加一些间距
        submit_layout.addSpacing(5)
        
        # Submit button
        self.submit_button = QPushButton("发送反馈(Ctrl+Enter 或 Cmd+Enter 提交)")
        self.submit_button.clicked.connect(self._submit_feedback)
        self.submit_button.setStyleSheet("""
            QPushButton {
                background-color: #666666;
                color: white;
                border: none;
                height:30px;
                line-height:30px;
                text-align:center;
                border-radius: 4px;
                font-size: 12px;
            }
            QPushButton:hover {
                background-color: #777777;
            }
            QPushButton:pressed {
                background-color: #555555;
            }
        """)
        submit_layout.addWidget(self.submit_button)
        
        layout.addLayout(submit_layout)
    
    def _create_progress_section(self, layout):
        """创建进度条区域"""
        progress_layout = QHBoxLayout()
        
        # Countdown progress bar section
        self.progress_bar = QProgressBar()
        self.progress_bar.setRange(0, self.timeout)
        self.progress_bar.setValue(self.elapsed_time)
        self.progress_bar.setFormat(self._format_time(self.elapsed_time))
        self.progress_bar.setStyleSheet("""
            QProgressBar {
                border: 1px solid #444;
                border-radius: 2px;
                background-color: #2b2b2b;
                height: 2px;
                color: white;
                font-size: 11px;
                text-align: right;
            }
            QProgressBar::chunk {
                background-color: qlineargradient(x1: 0, y1: 0, x2: 1, y2: 0,
                                                  stop: 0 #4CAF50, stop: 0.5 #45a049, stop: 1 #4CAF50);
                border-radius: 2px;
            }
        """)
        progress_layout.addWidget(self.progress_bar)
        layout.addLayout(progress_layout)
    
    def _handle_command_execution(self, command_content: str):
        """处理指令执行"""
        if command_content:
            self.command_executed.emit(command_content)
    
    def _execute_option_immediately(self, option_index: int):
        """立即执行选项"""
        self.option_executed.emit(option_index)
    
    def _show_command_popup(self):
        """显示指令弹窗"""
        try:
            # 确保输入框有焦点
            if self.feedback_text:
                self.feedback_text.setFocus()
                
                # 触发指令弹窗（默认显示项目指令）
                if hasattr(self.feedback_text, '_show_command_popup'):
                    self.feedback_text._show_command_popup("", "project")
                else:
                    QMessageBox.information(self, "提示", "指令功能暂不可用")

        except Exception as e:
            QMessageBox.critical(self, "错误", f"显示指令弹窗失败: {str(e)}")

    def _show_history(self):
        """显示历史记录"""
        try:
            # 加载历史记录
            history = self.get_recent_history()

            if not history:
                QMessageBox.information(self, "历史记录", "暂无历史记录")
                return

            # 检查弹窗组件是否可用
            if not HISTORY_POPUP_AVAILABLE:
                QMessageBox.critical(self, "错误", "历史记录弹窗组件不可用")
                return

            # 创建弹窗
            popup = HistoryPopup(self)

            # 设置历史记录数据
            popup.set_history_records(history, self)

            # 连接信号
            popup.content_inserted.connect(lambda content: self.feedback_text.insertPlainText(content))
            popup.content_copied.connect(lambda content: QApplication.clipboard().setText(content))
            popup.popup_closed.connect(lambda: None)  # 静默处理关闭事件

            # 获取主窗口（FeedbackUI）的位置和大小
            main_window = self.window()
            if main_window:
                # 获取主窗口的全局位置
                window_pos = main_window.mapToGlobal(QPoint(0, 0))
                # 弹窗左边缘与主窗口左边缘对齐
                popup_pos = QPoint(window_pos.x(), window_pos.y())
            else:
                # 如果找不到主窗口，使用按钮位置
                if hasattr(self, 'history_button') and self.history_button:
                    button = self.history_button
                    button_pos = button.mapToGlobal(button.rect().bottomLeft())
                    popup_pos = QPoint(button_pos.x() - 200, button_pos.y() + 5)
                else:
                    popup_pos = QPoint(100, 100)

            # 显示弹窗
            popup.show_at_position(popup_pos)

        except Exception as e:
            QMessageBox.critical(self, "错误", f"显示历史记录失败: {str(e)}")
    
    def _on_text_changed(self):
        """文本变化处理"""
        if self.feedback_text and self.submit_button:
            # 根据文本内容动态改变按钮颜色 - 与原版保持一致
            has_text = bool(self.feedback_text.toPlainText().strip())
            if has_text:
                # 有内容时，按钮变为蓝色（与原版一致）
                self.submit_button.setStyleSheet("""
                    QPushButton {
                        background-color: #2196F3;
                        color: white;
                        border: none;
                        height:30px;
                        line-height:30px;
                        text-align:center;
                        border-radius: 4px;
                        font-size: 12px;
                    }
                    QPushButton:hover {
                        background-color: #1976D2;
                    }
                    QPushButton:pressed {
                        background-color: #0D47A1;
                    }
                """)
            else:
                # 无内容时，按钮为灰色（与原版一致）
                self.submit_button.setStyleSheet("""
                    QPushButton {
                        background-color: #666666;
                        color: white;
                        border: none;
                        height:30px;
                        line-height:30px;
                        text-align:center;
                        border-radius: 4px;
                        font-size: 12px;
                    }
                    QPushButton:hover {
                        background-color: #777777;
                    }
                    QPushButton:pressed {
                        background-color: #555555;
                    }
                """)

        self.text_changed.emit()

    def _get_text_with_image_placeholders(self):
        """获取包含图片占位符的文本

        遍历文档内容，在图片位置插入占位符 [图片1]、[图片2] 等
        """
        if not self.feedback_text:
            return ""

        document = self.feedback_text.document()
        cursor = QTextCursor(document)
        cursor.movePosition(QTextCursor.Start)

        result_text = ""
        image_index = 1
        block = document.begin()

        # 遍历所有文本块
        while block.isValid():
            # 获取当前块的迭代器
            it = block.begin()

            # 遍历块中的所有片段
            while not it.atEnd():
                fragment = it.fragment()
                if fragment.isValid():
                    char_format = fragment.charFormat()

                    # 检查是否是图片格式
                    if char_format.isImageFormat():
                        # 插入图片占位符
                        result_text += f"[图片{image_index}]"
                        image_index += 1
                    else:
                        # 添加普通文本
                        result_text += fragment.text()

                it += 1

            # 添加块之间的换行符（除了最后一个块）
            block = block.next()
            if block.isValid():
                result_text += "\n"

        return result_text.strip()

    def _submit_feedback(self):
        """提交反馈"""
        if not self.feedback_text:
            return

        # 获取包含图片占位符的文本内容
        text_content = self._get_text_with_image_placeholders()
        images = self.feedback_text.get_pasted_images() if hasattr(self.feedback_text, 'get_pasted_images') else []
        
        # 获取选中的预定义选项
        selected_options = []
        for i, checkbox in enumerate(self.option_checkboxes):
            if checkbox.isChecked():
                selected_options.append(self.predefined_options[i])
        
        # 检查已选中的指令（优先使用新的指令标签机制）
        selected_command_content = ""
        if self.selected_command:
            # 使用新的指令标签机制
            selected_command_content = self.selected_command['content']
        elif hasattr(self, 'command_widget') and self.command_widget:
            # 兼容原有的指令选择方式
            for i in range(self.command_widget.count()):
                tab = self.command_widget.widget(i)
                # 检查是否有command_button_group（所有指令选项卡都有）
                if hasattr(tab, 'command_button_group'):
                    checked_button = tab.command_button_group.checkedButton()
                    if checked_button:
                        command_index = checked_button.property('command_index')
                        # 检查是否有commands数组（所有指令选项卡都有）
                        if (command_index is not None and
                            hasattr(tab, 'commands') and
                            0 <= command_index < len(tab.commands)):
                            selected_command_content = tab.commands[command_index]['content']
                            break  # 找到就停止查找
        
        # 构建结构化内容数组
        content_parts = []
        
        # 如果开启深度思考模式，在最前面添加提示
        if self.deep_thinking_mode:
            content_parts.append({
                "type": "text",
                "text": "**ultrathink**"
            })
        
        # 添加选中的预定义选项
        if selected_options:
            content_parts.append({
                "type": "options", 
                "text": "; ".join(selected_options)
            })
        
        # 添加选中的指令内容
        if selected_command_content:
            content_parts.append({
                "type": "command", 
                "text": selected_command_content
            })
        
        # 添加用户输入的文本
        if text_content:
            content_parts.append({
                "type": "text", 
                "text": text_content
            })
        
        # 保存到历史记录（保存用户发送的消息）
        # 组合所有内容：选项 + 指令 + 文本
        history_content_parts = []
        if selected_options:
            history_content_parts.append(f"🔘 用户选择的选项：\n{'; '.join(selected_options)}")
        if selected_command_content:
            history_content_parts.append(f"💻 用户输入的指令：\n{selected_command_content}")
        if text_content:
            history_content_parts.append(f"💬 用户输入的文本：\n{text_content}")

        # 如果有任何内容，保存到历史记录
        if history_content_parts:
            full_content = "\n\n".join(history_content_parts)
            self.save_to_history(full_content, 'sent')
        
        # 始终发送信号，即使content_parts为空（允许发送空反馈）
        self.feedback_submitted.emit(content_parts, images)
    
    def _format_time(self, seconds: int) -> str:
        """格式化时间显示"""
        if seconds < 60:
            return f"AI已等待: {seconds}秒"
        else:
            minutes = seconds // 60
            remaining_seconds = seconds % 60
            return f"AI已等待: {minutes}分{remaining_seconds}秒"
    
    def update_progress(self, elapsed_time: int):
        """更新进度条"""
        self.elapsed_time = elapsed_time
        if self.progress_bar:
            self.progress_bar.setValue(elapsed_time)
            self.progress_bar.setFormat(self._format_time(elapsed_time))
    
    def get_feedback_text(self) -> str:
        """获取反馈文本"""
        if self.feedback_text:
            return self.feedback_text.toPlainText().strip()
        return ""
    
    def get_selected_options(self) -> List[str]:
        """获取选中的预定义选项"""
        selected = []
        for i, checkbox in enumerate(self.option_checkboxes):
            if checkbox.isChecked():
                selected.append(self.predefined_options[i])
        return selected
    
    def _toggle_deep_thinking(self):
        """切换深度思考模式"""
        self.deep_thinking_mode = self.deep_thinking_button.isChecked()
        
        # 保存状态到设置
        self._save_deep_thinking_mode(self.deep_thinking_mode)
        
        # 更新工具提示
        if self.deep_thinking_button:
            if self.deep_thinking_mode:
                self.deep_thinking_button.setToolTip("深度思考模式已开启 (点击关闭)")
            else:
                self.deep_thinking_button.setToolTip("深度思考模式 (点击开启)")
    
    def _load_stage_info(self):
        """加载工作空间阶段信息"""
        # 如果没有session_id和workspace_id，直接返回
        if not self.session_id and not self.workspace_id:
            return

        try:
            # 导入工作空间管理器
            import sys
            parent_dir = os.path.dirname(os.path.dirname(os.path.abspath(__file__)))
            if parent_dir not in sys.path:
                sys.path.insert(0, parent_dir)
            from workspace_manager import WorkspaceManager

            # 创建管理器实例
            manager = WorkspaceManager(self.project_path)

            # 优先使用workspace_id，如果没有则使用session_id
            self.stage_info = manager.get_stage_info(
                session_id=self.session_id,
                workspace_id=self.workspace_id
            )
        except Exception as e:
            # 静默处理加载失败，不影响主流程
            self.stage_info = None

    def _load_workspace_context(self):
        """加载工作空间上下文信息（goal和对话标题）"""
        if not self.session_id:
            return

        try:
            # 导入工作空间管理器函数
            import sys
            parent_dir = os.path.dirname(os.path.dirname(os.path.abspath(__file__)))
            if parent_dir not in sys.path:
                sys.path.insert(0, parent_dir)
            from workspace_manager import get_workspace_goal_for_session, get_session_title_for_session

            # 获取工作空间goal
            self.workspace_goal = get_workspace_goal_for_session(self.session_id, self.project_path)

            # 获取对话标题（优先从workspace.yml的sessions获取，如果没有再使用work_title）
            session_title = get_session_title_for_session(self.session_id, self.project_path)
            if session_title:
                self.dialog_title = session_title
            else:
                self.dialog_title = self.work_title

        except Exception as e:
            # 静默处理加载失败，不影响主流程
            pass
            self.workspace_goal = None
            self.dialog_title = self.work_title

    def _create_stage_buttons(self, layout):
        """创建阶段切换按钮"""
        if not self.stage_info:
            return

        # 创建按钮容器
        stage_buttons_container = QWidget()
        stage_buttons_layout = QHBoxLayout(stage_buttons_container)
        stage_buttons_layout.setContentsMargins(5, 5, 5, 5)
        stage_buttons_layout.setSpacing(10)

        # 创建上一阶段按钮
        if self.stage_info.get('prev_stage'):
            prev_stage = self.stage_info['prev_stage']
            # 截断过长的标题
            title = prev_stage.get('title', '')
            if len(title) > 10:
                title = title[:10] + "..."
            prev_btn = QPushButton(f"上一阶段: {title}")
            prev_btn.setToolTip(prev_stage.get('description', ''))
            prev_btn.setCursor(Qt.PointingHandCursor)
            prev_btn.setSizePolicy(QSizePolicy.Expanding, QSizePolicy.Fixed)  # 水平扩展
            prev_btn.setStyleSheet("""
                QPushButton {
                    background-color: rgba(200, 200, 200, 25);
                    color: #AAA;
                    border: 1px solid rgba(200, 200, 200, 45);
                    padding: 6px 12px;
                    border-radius: 4px;
                    font-size: 13px;
                    text-align: center;
                    min-width: 0px;
                }
                QPushButton:hover {
                    background-color: rgba(200, 200, 200, 40);
                    border: 1px solid #BBB;
                    color: #888;
                }
                QPushButton:pressed {
                    background-color: rgba(200, 200, 200, 55);
                }
            """)
            prev_btn.clicked.connect(lambda: self._on_stage_button_clicked("请进入上一阶段"))
            stage_buttons_layout.addWidget(prev_btn, 1)  # 权重1，占50%
        else:
            # 如果没有上一阶段，添加一个占位空间
            stage_buttons_layout.addStretch(1)

        # 创建下一阶段按钮
        if self.stage_info.get('next_stage'):
            next_stage = self.stage_info['next_stage']
            # 截断过长的标题
            title = next_stage.get('title', '')
            if len(title) > 10:
                title = title[:10] + "..."
            next_btn = QPushButton(f"下一阶段: {title}")
            next_btn.setToolTip(next_stage.get('description', ''))
            next_btn.setCursor(Qt.PointingHandCursor)
            next_btn.setSizePolicy(QSizePolicy.Expanding, QSizePolicy.Fixed)  # 水平扩展
            next_btn.setStyleSheet("""
                QPushButton {
                    background-color: rgba(76, 175, 80, 30);
                    color: #4CAF50;
                    border: 1px solid rgba(76, 175, 80, 50);
                    padding: 6px 12px;
                    border-radius: 4px;
                    font-size: 13px;
                    text-align: center;
                    min-width: 0px;
                }
                QPushButton:hover {
                    background-color: rgba(76, 175, 80, 50);
                    border: 1px solid #4CAF50;
                }
                QPushButton:pressed {
                    background-color: rgba(76, 175, 80, 70);
                }
            """)
            next_btn.clicked.connect(lambda: self._on_stage_button_clicked("请进入下一阶段"))
            stage_buttons_layout.addWidget(next_btn, 1)  # 权重1，占50%
        else:
            # 如果没有下一阶段，添加一个占位空间
            stage_buttons_layout.addStretch(1)

        layout.addWidget(stage_buttons_container)

    def _create_next_task_button(self, layout):
        """创建下一任务按钮（独立方法）"""
        if not self.next_task:
            return

        next_task_title = self.next_task.get('title', '')
        # 如果标题过长，截断
        if len(next_task_title) > 20:
            next_task_title = next_task_title[:20] + "..."

        next_task_btn = QPushButton(f"下一任务: {next_task_title}")
        next_task_btn.setCursor(Qt.PointingHandCursor)
        next_task_btn.setSizePolicy(QSizePolicy.Expanding, QSizePolicy.Fixed)
        next_task_btn.setStyleSheet("""
            QPushButton {
                background-color: rgba(76, 175, 80, 30);
                color: #4CAF50;
                border: 1px solid rgba(76, 175, 80, 50);
                padding: 6px 12px;
                border-radius: 4px;
                font-size: 13px;
                text-align: center;
            }
            QPushButton:hover {
                background-color: rgba(76, 175, 80, 50);
                border: 1px solid #4CAF50;
            }
            QPushButton:pressed {
                background-color: rgba(76, 175, 80, 70);
            }
        """)
        next_task_btn.clicked.connect(self._on_next_task_clicked)
        layout.addWidget(next_task_btn)

    def _on_stage_button_clicked(self, message):
        """处理阶段切换按钮点击"""
        # 作为文本内容提交
        content_parts = [{
            "type": "text",
            "text": message
        }]
        self.feedback_submitted.emit(content_parts, [])
        # 关闭窗口（如果有父窗口）
        if self.parent() and hasattr(self.parent(), 'close'):
            self.parent().close()

    def _load_deep_thinking_mode(self) -> bool:
        """从设置中加载深度思考模式状态"""
        from PySide6.QtCore import QSettings
        
        # 优先尝试加载项目级设置
        if self.project_path:
            project_settings_file = os.path.join(self.project_path, '.feedback_settings.json')
            if os.path.exists(project_settings_file):
                try:
                    with open(project_settings_file, 'r') as f:
                        settings = json.load(f)
                        return settings.get('deep_thinking_mode', False)
                except Exception:
                    pass  # 如果读取失败，使用全局设置
        
        # 使用全局QSettings
        settings = QSettings("FeedbackUI", "ChatTab")
        return settings.value("deep_thinking_mode", False, type=bool)
    
    def _save_deep_thinking_mode(self, enabled: bool):
        """保存深度思考模式状态到设置"""
        from PySide6.QtCore import QSettings
        
        # 保存到项目级设置（如果有项目路径）
        if self.project_path:
            project_settings_file = os.path.join(self.project_path, '.feedback_settings.json')
            settings = {}
            
            # 读取现有设置
            if os.path.exists(project_settings_file):
                try:
                    with open(project_settings_file, 'r') as f:
                        settings = json.load(f)
                except Exception:
                    settings = {}
            
            # 更新深度思考模式设置
            settings['deep_thinking_mode'] = enabled
            
            # 保存回文件
            try:
                with open(project_settings_file, 'w') as f:
                    json.dump(settings, f, indent=2)
            except Exception:
                pass  # 如果保存失败，至少保存到全局设置
        
        # 同时保存到全局QSettings
        settings = QSettings("FeedbackUI", "ChatTab")
        settings.setValue("deep_thinking_mode", enabled)
    
    def get_history_file_path(self) -> Optional[str]:
        """获取历史记录文件路径"""
        # 如果没有session_id,返回None
        if not self.session_id:
            return None

        if self.project_path:
            return os.path.join(self.project_path, '.workspace', 'chat_history', f'{self.session_id}.json')
        else:
            # 如果没有项目路径，使用脚本目录
            script_dir = os.path.dirname(os.path.abspath(__file__))
            return os.path.join(script_dir, '..', '.workspace', 'chat_history', f'{self.session_id}.json')
    
    def save_to_history(self, content: str, message_type: str = 'sent', ai_response: str = None) -> bool:
        """保存内容到历史记录

        Args:
            content: 要保存的内容
            message_type: 消息类型 ('sent' 或 'received')
            ai_response: AI的回复内容（如果有）

        Returns:
            bool: 保存是否成功
        """
        if not content.strip() and not ai_response:
            return False

        try:
            # 获取历史记录文件路径
            history_file = self.get_history_file_path()

            # 如果没有session_id,静默跳过
            if not history_file:
                return False

            # 读取现有历史记录
            history = self.load_history_from_file()

            # 创建对话记录
            new_record = {
                'type': 'dialogue',  # 标记为对话类型
                'timestamp': datetime.now().isoformat(),
                'time_display': datetime.now().strftime('%Y-%m-%d %H:%M:%S'),
                'messages': []
            }

            # 添加用户消息
            if content.strip():
                new_record['messages'].append({
                    'role': 'user',
                    'content': content.strip(),
                    'time': datetime.now().strftime('%H:%M:%S')
                })

            # 添加AI回复（如果有）
            if ai_response:
                new_record['messages'].append({
                    'role': 'assistant',
                    'content': ai_response.strip(),
                    'time': datetime.now().strftime('%H:%M:%S')
                })

            history.append(new_record)

            # 保存到文件(不再限制数量)
            os.makedirs(os.path.dirname(history_file), exist_ok=True)
            with open(history_file, 'w', encoding='utf-8') as f:
                json.dump(history, f, ensure_ascii=False, indent=2)

            return True

        except Exception:
            # 静默处理保存失败，不影响主流程
            return False

    def save_response_to_history(self, response: str) -> bool:
        """保存AI回复到当前对话历史

        Args:
            response: AI的回复内容

        Returns:
            bool: 保存是否成功
        """
        if not response.strip():
            return False

        try:
            # 获取历史记录文件路径
            history_file = self.get_history_file_path()

            # 如果没有session_id,静默跳过
            if not history_file:
                return False

            # 读取现有历史记录
            history = self.load_history_from_file()

            if history and history[-1].get('type') == 'dialogue':
                # 在最后一个对话记录中添加AI回复
                history[-1]['messages'].append({
                    'role': 'assistant',
                    'content': response.strip(),
                    'time': datetime.now().strftime('%H:%M:%S')
                })
            else:
                # 创建新的对话记录（仅包含AI回复）
                new_record = {
                    'type': 'dialogue',
                    'timestamp': datetime.now().isoformat(),
                    'time_display': datetime.now().strftime('%Y-%m-%d %H:%M:%S'),
                    'messages': [{
                        'role': 'assistant',
                        'content': response.strip(),
                        'time': datetime.now().strftime('%H:%M:%S')
                    }]
                }
                history.append(new_record)

            # 保存到文件(不再限制数量)
            os.makedirs(os.path.dirname(history_file), exist_ok=True)
            with open(history_file, 'w', encoding='utf-8') as f:
                json.dump(history, f, ensure_ascii=False, indent=2)

            return True

        except Exception:
            # 静默处理保存失败，不影响主流程
            return False
    
    def load_history_from_file(self) -> List[Dict]:
        """从文件加载历史记录"""
        try:
            history_file = self.get_history_file_path()

            # 如果没有session_id,静默跳过
            if not history_file:
                return []

            if os.path.exists(history_file):
                with open(history_file, 'r', encoding='utf-8') as f:
                    history = json.load(f)
                    if isinstance(history, list):
                        # 兼容旧格式：将旧格式转换为新的对话格式
                        converted_history = []
                        for record in history:
                            if 'type' not in record:  # 旧格式
                                converted_record = {
                                    'type': 'dialogue',
                                    'timestamp': record.get('timestamp', ''),
                                    'time_display': record.get('time_display', ''),
                                    'messages': [{
                                        'role': 'user',
                                        'content': record.get('content', ''),
                                        'time': record.get('time_display', '').split(' ')[-1] if 'time_display' in record else ''
                                    }]
                                }
                                converted_history.append(converted_record)
                            else:
                                converted_history.append(record)
                        return converted_history
                    return []
            return []
        except Exception:
            # 静默处理加载失败，不影响主流程
            return []
    
    def get_recent_history(self, count: Optional[int] = None) -> List[Dict]:
        """获取最近的历史记录

        Args:
            count: 获取记录数量，如果为None则返回所有记录

        Returns:
            List[Dict]: 历史记录列表
        """
        history = self.load_history_from_file()
        if count is None:
            return history  # 返回所有历史记录
        return history[-count:]
    
    def save_input_to_history(self):
        """保存输入框内容到历史记录（用于超时或关闭时自动保存）

        增强版：同时保存选项、指令和文本内容
        """
        if not self.feedback_text:
            return

        # 获取输入框中的文本内容
        text_content = self.feedback_text.toPlainText().strip()

        # 获取选中的预定义选项
        selected_options = []
        for i, checkbox in enumerate(self.option_checkboxes):
            if checkbox.isChecked():
                selected_options.append(self.predefined_options[i])

        # 获取选中的指令内容
        selected_command_content = ""
        if self.selected_command:
            selected_command_content = self.selected_command['content']

        # 组合所有内容
        history_content_parts = []
        if selected_options:
            history_content_parts.append(f"🔘 用户选择的选项：\n{'; '.join(selected_options)}")
        if selected_command_content:
            history_content_parts.append(f"💻 用户输入的指令：\n{selected_command_content}")
        if text_content:
            history_content_parts.append(f"💬 用户输入的文本：\n{text_content}")

        # 如果有任何内容，保存到历史记录（标记为未提交）
        if history_content_parts:
            full_content = "\n\n".join(history_content_parts)
            # 添加未提交标记
            full_content = f"⚠️ 【未提交 - 超时/关闭时自动保存】\n\n{full_content}"
            self.save_to_history(full_content, 'draft')
    
    def clear_feedback(self):
        """清空反馈内容"""
        if self.feedback_text:
            self.feedback_text.clear()
            if hasattr(self.feedback_text, 'clear_images'):
                self.feedback_text.clear_images()
        
        # 清空选项
        for checkbox in self.option_checkboxes:
            checkbox.setChecked(False)
        
        # 清空选中的指令
        self._clear_selected_command()

    def _get_configured_ide_or_prompt(self):
        """获取配置的IDE,如果未配置则弹出设置对话框,返回IDE名称或None"""
        try:
            from feedback_config import FeedbackConfig

            # 获取项目路径
            project_path = self.project_path if hasattr(self, 'project_path') else None
            if not project_path and hasattr(self, 'parent'):
                main_window = self.parent()
                while main_window and not hasattr(main_window, 'project_path'):
                    main_window = main_window.parent()
                if main_window:
                    project_path = main_window.project_path

            if not project_path:
                return None

            config_manager = FeedbackConfig(project_path)
            ide = config_manager.get_ide() or os.getenv('IDE')

            if not ide:
                # 弹出设置IDE对话框
                reply = QMessageBox.question(
                    self,
                    "未配置IDE",
                    "尚未配置默认IDE，是否现在设置？",
                    QMessageBox.Yes | QMessageBox.No
                )
                if reply == QMessageBox.Yes:
                    # 获取主窗口并调用设置对话框
                    main_window = self.parent()
                    while main_window and not hasattr(main_window, '_show_ide_settings_dialog'):
                        main_window = main_window.parent()
                    if main_window:
                        main_window._show_ide_settings_dialog()
                        # 重新获取配置
                        ide = config_manager.get_ide()

            return ide
        except Exception as e:
            print(f"获取IDE配置失败: {e}")
            return None

    def _edit_selected_command(self):
        """在IDE中打开选中的指令文件"""
        if not self.selected_command:
            return

        # 优先使用保存的文件路径
        file_path = self.selected_command.get('full_path', '')

        # 如果没有保存路径，则尝试查找
        if not file_path:
            command_data = {
                'title': self.selected_command['title'],
                'content': self.selected_command['content'],
                'type': self.selected_command['type'],
            }
            file_path = self._find_command_file_path(command_data)

        if not file_path or not os.path.exists(file_path):
            QMessageBox.warning(self, "打开失败", f"无法找到指令文件\n标题: {self.selected_command.get('title')}\n路径: {file_path or '未找到'}")
            return

        # 使用IDE打开文件
        try:
            # 导入ide_utils模块
            import sys
            parent_dir = os.path.dirname(os.path.dirname(os.path.abspath(__file__)))
            if parent_dir not in sys.path:
                sys.path.insert(0, parent_dir)
            from ide_utils import open_project_with_ide

            # 使用统一的IDE获取方法
            ide_name = self._get_configured_ide_or_prompt()

            if not ide_name:
                # 用户取消了设置IDE或无法获取配置
                return

            # 使用IDE打开文件
            success = open_project_with_ide(file_path, ide_name)

            if not success:
                # 如果IDE打开失败，使用系统默认编辑器
                import subprocess
                import platform

                if platform.system() == "Darwin":
                    subprocess.run(["open", file_path], check=True)
                elif platform.system() == "Windows":
                    os.startfile(file_path)
                else:
                    subprocess.run(["xdg-open", file_path], check=True)

        except Exception as e:
            QMessageBox.critical(self, "打开失败", f"无法打开指令文件: {str(e)}")
    
    def _find_command_file_path(self, command_data):
        """查找指令文件路径"""
        import os

        # 获取项目路径
        project_path = self.project_path if hasattr(self, 'project_path') else None
        if not project_path:
            # 从父窗口获取
            main_window = self.parent()
            while main_window and not hasattr(main_window, 'project_path'):
                main_window = main_window.parent()
            if main_window:
                project_path = main_window.project_path

        if not project_path:
            return None

        title = command_data['title']
        if title.endswith('.md'):
            title = title[:-3]

        # 根据指令类型确定搜索目录
        if command_data['type'] == 'project':
            search_dirs = [
                os.path.join(project_path, ".claude", "commands"),
                os.path.join(project_path, "_agent-local", "prompts"),
                os.path.join(project_path, ".cursor", "rules")
            ]
        elif command_data['type'] == 'personal':
            search_dirs = [
                os.path.join(project_path, "prompts"),
                os.path.expanduser("~/.claude/commands")
            ]
        else:  # system
            search_dirs = [
                os.path.join(project_path, ".claude", "commands"),
                os.path.join(project_path, "src-min")
            ]

        # 在各个目录中搜索文件
        for search_dir in search_dirs:
            if not os.path.exists(search_dir):
                continue

            # 尝试不同的文件扩展名
            for ext in ['.md', '.mdc', '.txt']:
                file_path = os.path.join(search_dir, f"{title}{ext}")
                if os.path.exists(file_path):
                    return file_path

            # 递归搜索子目录
            try:
                for root, dirs, files in os.walk(search_dir):
                    for file in files:
                        if file.startswith(title) and file.endswith(('.md', '.mdc', '.txt')):
                            return os.path.join(root, file)
            except Exception:
                pass

        return None

    def _load_task_info(self):
        """加载任务信息"""
        if not self.session_id:
            return

        try:
            if not self.project_path:
                return

            # 构建任务文件路径
            task_file = os.path.join(self.project_path, '.workspace', 'tasks', f'{self.session_id}.json')
            if not os.path.exists(task_file):
                return

            # 读取任务文件
            with open(task_file, 'r', encoding='utf-8') as f:
                data = json.load(f)
                tasks = data.get('tasks', [])

            # 查找当前任务（state == "in_progress"）
            for task in tasks:
                if task.get('state') == 'in_progress':
                    self.current_task = {
                        'id': task.get('id'),
                        'title': task.get('title', ''),
                        'state': task.get('state')
                    }
                    break

            # 查找下一个任务（state == "pending"）
            for task in tasks:
                if task.get('state') == 'pending':
                    self.next_task = {
                        'id': task.get('id'),
                        'title': task.get('title', ''),
                        'state': task.get('state')
                    }
                    break

        except Exception:
            # 静默处理加载失败，不影响主流程
            pass

    def _create_current_task_label(self, layout):
        """创建当前任务显示标签"""
        if not self.current_task:
            return

        task_title = self.current_task.get('title', '')
        task_label = QLabel(f"📌 当前任务: {task_title}")
        task_label.setWordWrap(True)
        task_label.setAlignment(Qt.AlignCenter)
        task_label.setStyleSheet("""
            QLabel {
                font-size: 13px;
                font-weight: bold;
                color: #FF8C00;
                padding: 6px;
                background-color: rgba(255, 140, 0, 10);
                border: 1px solid rgba(255, 140, 0, 30);
                border-radius: 4px;
                margin: 5px 0px;
            }
        """)
        layout.addWidget(task_label)

    def _on_next_task_clicked(self):
        """处理下一任务按钮点击"""
        content_parts = [{
            "type": "text",
            "text": "请开始任务列表中的下一个任务"
        }]
        self.feedback_submitted.emit(content_parts, [])
        # 关闭窗口（如果有父窗口）
        if self.parent() and hasattr(self.parent(), 'close'):
            self.parent().close()


"""
上下文信息格式化模块
用于格式化工作空间、阶段、任务等上下文信息
"""
import json
from pathlib import Path
from typing import Optional, Dict, Any
from workspace_manager import WorkspaceManager, get_session_title_for_session


def load_task_list(session_id: str, project_path: str = None) -> list:
    """加载任务列表

    Args:
        session_id: 会话ID
        project_path: 项目路径

    Returns:
        任务列表，每个任务包含 id, title, state
    """
    try:
        if not project_path:
            project_path = Path.cwd()
        else:
            project_path = Path(project_path)

        task_file = project_path / '.workspace' / 'tasks' / f'{session_id}.json'
        if not task_file.exists():
            return []

        with open(task_file, 'r', encoding='utf-8') as f:
            data = json.load(f)
            return data.get('tasks', [])
    except Exception:
        return []


def format_for_stop_hook(session_id: str, project_path: str = None) -> str:
    """格式化上下文信息用于stop hook

    Args:
        session_id: 会话ID
        project_path: 项目路径

    Returns:
        格式化的上下文信息字符串
    """
    lines = []
    has_content = False

    # 获取会话标题
    session_title = get_session_title_for_session(session_id, project_path)

    # 获取阶段信息
    workspace_mgr = WorkspaceManager(project_path)
    stage_info = workspace_mgr.get_stage_info(session_id)

    # 获取任务列表
    tasks = load_task_list(session_id, project_path)

    # 只有在有阶段信息或任务列表时才显示
    if stage_info or tasks or session_title:
        lines.append("# 当前上下文相关信息：")
        lines.append("")
        has_content = True

    # 显示会话标题（仅当有值时）
    if session_title:
        # 检查是否为默认的新会话标题（包含"新会话"或以"New conversation"开头）
        if "新会话" in session_title or session_title.startswith("New conversation"):
            lines.append("## 当前会话标题：" + session_title)
            lines.append("⚠️ **提醒：请根据工作内容及时更新会话标题**")
            lines.append("")
        else:
            lines.append("## 当前会话标题：" + session_title)
            lines.append("")

    # 显示阶段信息（仅当有值时）
    if stage_info:
        current_stage = stage_info.get('current_stage', {})
        next_stage = stage_info.get('next_stage', {})

        if current_stage and current_stage.get('title'):
            lines.append(f"## 当前阶段：{current_stage.get('title')}")

        if next_stage and next_stage.get('title'):
            lines.append(f"## 下一个阶段：{next_stage.get('title')}")
        elif current_stage:  # 有当前阶段但没有下一阶段
            lines.append("## 下一个阶段：已完成所有阶段")

    # 显示任务列表（仅当有任务时）
    if tasks:
        lines.append("## 任务列表：")

        for task in tasks:
            state = task.get('state', 'pending')
            title = task.get('title', '未命名任务')
            task_id = task.get('id', '')

            # 简化标题显示
            if '(执行前请查看该步骤的详细规则)' in title:
                title = title.replace('(执行前请查看该步骤的详细规则)', '').strip()

            if state == 'completed':
                checkbox = '[x]'
            elif state == 'in_progress':
                checkbox = '[~]'
            else:
                checkbox = '[ ]'

            lines.append(f"- {checkbox} {task_id}. {title}")

        lines.append("")

    # 添加提示信息
    if has_content:
        lines.append("请分析接下来的行动计划，是继续自动工作还是使用 feedback 工具向用户反馈/请示")
        lines.append("")
        lines.append(f"当前的 session_id:{session_id}")
    else:
        # 没有上下文信息时的简化提示
        lines.append("请使用 feedback 工具向用户反馈/请示")
        lines.append("")
        lines.append(f"当前的 session_id:{session_id}")

    return "\n".join(lines)


def format_context_info(session_id: str, project_path: str = None) -> Optional[str]:
    """格式化上下文信息（仅用于显示给用户）

    Args:
        session_id: 会话ID
        project_path: 项目路径

    Returns:
        格式化的上下文信息字符串，如果没有上下文信息则返回None
    """
    lines = []
    has_content = False

    # 获取阶段信息
    workspace_mgr = WorkspaceManager(project_path)
    stage_info = workspace_mgr.get_stage_info(session_id)

    # 获取任务列表
    tasks = load_task_list(session_id, project_path)

    # 只有在有阶段信息或任务列表时才添加内容
    if not stage_info and not tasks:
        return None

    lines.append("## 📋 当前上下文")
    lines.append("")

    # 显示阶段信息（仅当有值时）
    if stage_info:
        current_stage = stage_info.get('current_stage', {})
        next_stage = stage_info.get('next_stage', {})

        if current_stage and current_stage.get('title'):
            lines.append(f"**当前阶段**: {current_stage.get('title')}")
            has_content = True

        if next_stage and next_stage.get('title'):
            lines.append(f"**下一阶段**: {next_stage.get('title')}")
            has_content = True
        elif current_stage:  # 有当前阶段但没有下一阶段
            lines.append("**下一阶段**: 已完成所有阶段")
            has_content = True

        if has_content:
            lines.append("")

    # 显示任务列表（仅当有任务时）
    if tasks:
        # 找出当前任务和下一任务
        current_task = None
        next_task = None

        for i, task in enumerate(tasks):
            state = task.get('state', 'pending')
            if state == 'in_progress':
                current_task = task
                # 找下一个待处理的任务
                for j in range(i + 1, len(tasks)):
                    if tasks[j].get('state', 'pending') == 'pending':
                        next_task = tasks[j]
                        break
                break

        # 如果没有进行中的任务，找第一个待处理的任务
        if not current_task:
            for task in tasks:
                if task.get('state', 'pending') == 'pending':
                    current_task = task
                    # 找下一个
                    idx = tasks.index(task)
                    for j in range(idx + 1, len(tasks)):
                        if tasks[j].get('state', 'pending') == 'pending':
                            next_task = tasks[j]
                            break
                    break

        if current_task:
            title = current_task.get('title', '未命名任务')
            # 简化标题显示
            if '(执行前请查看该步骤的详细规则)' in title:
                title = title.replace('(执行前请查看该步骤的详细规则)', '').strip()
            lines.append(f"**当前任务**: {title}")
            has_content = True

        if next_task:
            title = next_task.get('title', '未命名任务')
            # 简化标题显示
            if '(执行前请查看该步骤的详细规则)' in title:
                title = title.replace('(执行前请查看该步骤的详细规则)', '').strip()
            lines.append(f"**下一任务**: {title}")
            has_content = True
        elif current_task and not next_task:
            lines.append("**下一任务**: 无（已是最后一个任务）")
            has_content = True

    if not has_content:
        return None

    return "\n".join(lines)


def format_for_feedback(session_id: str, project_path: str = None) -> Optional[str]:
    """格式化完整的feedback信息(AI规则+上下文),用于返回给AI

    Args:
        session_id: 会话ID
        project_path: 项目路径

    Returns:
        格式化的完整信息字符串，如果没有上下文信息则返回None
    """
    # 获取阶段信息
    workspace_mgr = WorkspaceManager(project_path)
    stage_info = workspace_mgr.get_stage_info(session_id)

    # 获取任务列表
    tasks = load_task_list(session_id, project_path)

    # 只有在有阶段信息或任务列表时才添加内容
    if not stage_info and not tasks:
        return None

    lines = []
    lines.append("## AI(你的)工作规则")
    lines.append("")
    lines.append("### 核心原则")
    lines.append("1. **严格遵循当前阶段**: 只能执行当前阶段的工作内容")
    lines.append("2. **严格遵循任务顺序**: 只能执行当前任务,完成后才能进入下一任务")
    lines.append("3. **禁止跨阶段**: feedback反馈选项只能针对『当前阶段』或『下一阶段』,禁止跨过下一阶段")
    lines.append("")
    lines.append("### Feedback使用规则(必须遵守)")
    lines.append("**禁止反馈以下内容:**")
    lines.append("- ❌ '好的,需求分析已确认'(没有实际工作)")
    lines.append("- ❌ '现在我将切换到下一阶段'(意图声明)")
    lines.append("- ❌ '让我开始XXX'(计划声明)")
    lines.append("- ❌ '我正在XXX'(进度声明)")
    lines.append("")
    lines.append("**只能反馈:**")
    lines.append("- ✓ 已完成的工作结果")
    lines.append("- ✓ 需要用户确认/选择的事项")
    lines.append("- ✓ 遇到的问题需要用户解决")
    lines.append("")
    lines.append("**正确流程:**")
    lines.append("用户要求切换阶段 → 先调用workspace_next_stage → 再开始工作 → 完成后再feedback")
    lines.append("")
    lines.append("### 反馈选项约束")
    lines.append("**允许的反馈选项:**")
    lines.append("- ✓ 当前阶段的操作 (如『继续当前工作』『修改当前成果』等)")
    lines.append("- ✓ 进入下一阶段 (如『确认,进入<下一阶段名称>』)")
    lines.append("")
    lines.append("**禁止的反馈选项:**")
    lines.append("- ❌ 跨过下一阶段的操作 (如当前=阶段1,下一=阶段2,禁止出现『直接进入阶段3』)")
    lines.append("- ❌ 跳过当前阶段的流程 (如当前阶段未完成就提供后续阶段的选项)")
    lines.append("")
    lines.append("### 操作检查清单")
    lines.append("在提供feedback选项前,必须检查:")
    lines.append("1. ✓ 当前阶段名称是什么?")
    lines.append("2. ✓ 下一阶段名称是什么?")
    lines.append("3. ✓ 我提供的选项是否只涉及『当前阶段』或『下一阶段』?")
    lines.append("4. ✓ 是否有跨过下一阶段的选项? (有则删除)")
    lines.append("")
    lines.append("### 示例说明")
    lines.append("假设: 当前阶段=A, 下一阶段=B, 再下一阶段=C")
    lines.append("- ✓ 正确: 反馈选项『继续A阶段工作』『完成A进入B阶段』")
    lines.append("- ❌ 错误: 反馈选项『继续A阶段工作』『直接进入C阶段』(跨过了B)")
    lines.append("")

    # 添加上下文信息
    context_info = format_context_info(session_id, project_path)
    if context_info:
        lines.append(context_info)

    return "\n".join(lines)



#!/usr/bin/env python3
"""
会话状态管理器
用于管理stop hook和feedback UI之间的会话状态，避免死循环
"""
import json
import os
import sys
from datetime import datetime, timedelta
from pathlib import Path
from typing import Optional, Dict, Any

class SessionManager:
    """管理会话状态，避免stop hook死循环"""
    
    def __init__(self, state_file: Optional[str] = None):
        """初始化会话管理器
        
        Args:
            state_file: 状态文件路径，默认为脚本同目录的session_states.json
        """
        if state_file:
            self.state_file = Path(state_file)
        else:
            # 使用相对路径，与脚本在同一目录
            script_dir = Path(__file__).parent
            self.state_file = script_dir / 'session_states.json'
        
        self.sessions = self._load_sessions()
        self._cleanup_old_sessions()
    
    def _load_sessions(self) -> Dict[str, Dict[str, Any]]:
        """加载会话状态"""
        if not self.state_file.exists():
            return {"sessions": {}}
        
        try:
            with open(self.state_file, 'r', encoding='utf-8') as f:
                data = json.load(f)
                return data if isinstance(data, dict) else {"sessions": {}}
        except (json.JSONDecodeError, IOError):
            return {"sessions": {}}
    
    def _save_sessions(self):
        """保存会话状态"""
        try:
            with open(self.state_file, 'w', encoding='utf-8') as f:
                json.dump(self.sessions, f, indent=2, ensure_ascii=False)
        except IOError as e:
            print(f"Error saving sessions: {e}", file=sys.stderr)
    
    def _cleanup_old_sessions(self):
        """清理超过24小时的旧会话"""
        if "sessions" not in self.sessions:
            self.sessions["sessions"] = {}
            return
        
        current_time = datetime.now()
        sessions_to_remove = []
        
        for session_id, session_data in self.sessions["sessions"].items():
            if "timestamp" in session_data:
                try:
                    session_time = datetime.fromisoformat(session_data["timestamp"])
                    if current_time - session_time > timedelta(hours=24):
                        sessions_to_remove.append(session_id)
                except (ValueError, TypeError):
                    sessions_to_remove.append(session_id)
        
        for session_id in sessions_to_remove:
            del self.sessions["sessions"][session_id]
        
        if sessions_to_remove:
            self._save_sessions()
    
    def get_session_status(self, session_id: str) -> Optional[str]:
        """获取会话状态
        
        Args:
            session_id: 会话ID
            
        Returns:
            会话状态: "user_closed", "active", "feedback_pending" 或 None
        """
        if "sessions" not in self.sessions:
            return None
        
        session = self.sessions["sessions"].get(session_id)
        if session:
            return session.get("status")
        return None
    
    def set_session_status(self, session_id: str, status: str, action: Optional[str] = None):
        """设置会话状态

        Args:
            session_id: 会话ID
            status: 状态 ("user_closed", "active", "feedback_pending")
            action: 最后的动作描述
        """
        if "sessions" not in self.sessions:
            self.sessions["sessions"] = {}

        # 保留现有的block_count（如果存在）
        existing_session = self.sessions["sessions"].get(session_id, {})
        block_count = existing_session.get("block_count", 0)

        self.sessions["sessions"][session_id] = {
            "status": status,
            "timestamp": datetime.now().isoformat(),
            "last_action": action or status,
            "block_count": block_count
        }
        self._save_sessions()
    
    def is_feedback_closed(self, session_id: str) -> bool:
        """检查会话是否因用户关闭feedback而结束
        
        Args:
            session_id: 会话ID
            
        Returns:
            True如果用户主动关闭了feedback窗口
        """
        status = self.get_session_status(session_id)
        return status == "user_closed"
    
    def mark_feedback_closed(self, session_id: str):
        """标记feedback被用户关闭（通用方法，保留向后兼容）

        Args:
            session_id: 会话ID
        """
        self.set_session_status(session_id, "user_closed", "feedback_window_closed_by_user")

    def mark_user_closed_by_button(self, session_id: str):
        """标记用户点击关闭按钮

        Args:
            session_id: 会话ID
        """
        self.set_session_status(session_id, "user_closed_by_button", "user_clicked_close_button")

    def mark_timeout_closed(self, session_id: str):
        """标记超时自动关闭

        Args:
            session_id: 会话ID
        """
        self.set_session_status(session_id, "timeout_closed", "feedback_timeout_auto_closed")

    def is_user_closed_by_button(self, session_id: str) -> bool:
        """检查是否用户点击关闭按钮

        Args:
            session_id: 会话ID

        Returns:
            True如果用户点击关闭按钮
        """
        status = self.get_session_status(session_id)
        return status == "user_closed_by_button"

    def is_timeout_closed(self, session_id: str) -> bool:
        """检查是否超时关闭

        Args:
            session_id: 会话ID

        Returns:
            True如果超时自动关闭
        """
        status = self.get_session_status(session_id)
        return status == "timeout_closed"

    def reset_on_feedback_show(self, session_id: str):
        """feedback展示时重置状态

        Args:
            session_id: 会话ID
        """
        # 清除所有状态，包括block_count
        self.clear_session(session_id)
    
    def get_block_count(self, session_id: str) -> int:
        """获取会话的阻止次数

        Args:
            session_id: 会话ID

        Returns:
            阻止次数
        """
        if "sessions" not in self.sessions:
            return 0

        session = self.sessions["sessions"].get(session_id, {})
        return session.get("block_count", 0)

    def increment_block_count(self, session_id: str) -> int:
        """增加会话的阻止次数

        Args:
            session_id: 会话ID

        Returns:
            更新后的阻止次数
        """
        if "sessions" not in self.sessions:
            self.sessions["sessions"] = {}

        if session_id not in self.sessions["sessions"]:
            self.sessions["sessions"][session_id] = {
                "status": "active",
                "timestamp": datetime.now().isoformat(),
                "block_count": 0
            }

        self.sessions["sessions"][session_id]["block_count"] = \
            self.sessions["sessions"][session_id].get("block_count", 0) + 1
        self.sessions["sessions"][session_id]["timestamp"] = datetime.now().isoformat()
        self._save_sessions()

        return self.sessions["sessions"][session_id]["block_count"]

    def clear_session(self, session_id: str):
        """清除会话状态

        Args:
            session_id: 会话ID
        """
        if "sessions" in self.sessions and session_id in self.sessions["sessions"]:
            del self.sessions["sessions"][session_id]
            self._save_sessions()


def main():
    """命令行接口"""
    import argparse
    
    parser = argparse.ArgumentParser(description='管理会话状态')
    parser.add_argument('action', choices=['get', 'set', 'check', 'mark_closed', 'clear'],
                        help='要执行的操作')
    parser.add_argument('session_id', help='会话ID')
    parser.add_argument('--status', help='设置的状态 (用于set操作)')
    parser.add_argument('--state-file', help='状态文件路径')
    
    args = parser.parse_args()
    
    manager = SessionManager(args.state_file)
    
    if args.action == 'get':
        status = manager.get_session_status(args.session_id)
        print(status if status else "none")
        
    elif args.action == 'set':
        if not args.status:
            print("Error: --status required for set action", file=sys.stderr)
            sys.exit(1)
        manager.set_session_status(args.session_id, args.status)
        print(f"Session {args.session_id} status set to {args.status}")
        
    elif args.action == 'check':
        is_closed = manager.is_feedback_closed(args.session_id)
        print("closed" if is_closed else "active")
        sys.exit(0 if not is_closed else 1)
        
    elif args.action == 'mark_closed':
        manager.mark_feedback_closed(args.session_id)
        print(f"Session {args.session_id} marked as closed by user")
        
    elif args.action == 'clear':
        manager.clear_session(args.session_id)
        print(f"Session {args.session_id} cleared")


if __name__ == "__main__":
    main()


"""
添加指令对话框组件
独立的UI组件，用于创建自定义指令文件
"""

import os
import sys
import re
from typing import Optional, Dict, Any

try:
    from PySide6.QtWidgets import (
        QDialog, QVBoxLayout, QHBoxLayout, QLabel, QLineEdit, 
        QTextEdit, QPushButton, QMessageBox, QFormLayout, QRadioButton, QButtonGroup, QWidget, QApplication
    )
    from PySide6.QtCore import Qt, QTimer
    from PySide6.QtGui import QFont
except ImportError:
    from PyQt5.QtWidgets import (
        QDialog, QVBoxLayout, QHBoxLayout, QLabel, QLineEdit, 
        QTextEdit, QPushButton, QMessageBox, QFormLayout, QRadioButton, QButtonGroup, QWidget, QApplication
    )
    from PyQt5.QtCore import Qt, QTimer
    from PyQt5.QtGui import QFont

# 导入路径配置模块
try:
    from path_config import get_path_config
    PATH_CONFIG_AVAILABLE = True
except ImportError:
    PATH_CONFIG_AVAILABLE = False

# 导入调试日志模块
try:
    from debug_logger import get_debug_logger
    DEBUG_LOG_AVAILABLE = True
except ImportError:
    DEBUG_LOG_AVAILABLE = False


class AddCommandDialog(QDialog):
    """添加指令对话框"""
    
    def __init__(self, project_path: str, parent=None):
        super().__init__(parent)
        self.project_path = project_path
        # 获取路径配置实例
        if PATH_CONFIG_AVAILABLE:
            self.path_config = get_path_config()
        else:
            self.path_config = None
        
        self.setWindowTitle("添加新指令")
        self.setModal(True)
        self.resize(500, 400)
        
        self._create_ui()
        self._apply_styles()
        
        # 连接信号
        self.title_input.textChanged.connect(self._update_button_state)
        self.content_input.textChanged.connect(self._update_button_state)
        
        # 设置初始状态
        self._update_button_state()
    
    def _create_ui(self):
        """创建对话框UI"""
        layout = QVBoxLayout(self)
        layout.setSpacing(15)
        layout.setContentsMargins(20, 20, 20, 20)
        
        # 表单区域
        form_layout = QFormLayout()
        form_layout.setSpacing(10)
        
        # 指令保存位置说明
        location_label = QLabel()
        display_path = self.path_config.get_project_commands_display_path() if self.path_config else ".claude/commands/"
        location_label.setText(f"指令将保存到: {display_path}")
        location_label.setStyleSheet("color: #888; font-style: italic;")
        form_layout.addRow("保存位置:", location_label)
        
        # 指令标题输入
        self.title_input = QLineEdit()
        self.title_input.setPlaceholderText("请输入指令标题（将作为文件名）")
        self.title_input.setMinimumHeight(35)
        form_layout.addRow("指令标题:", self.title_input)
        
        layout.addLayout(form_layout)
        
        # 指令内容输入
        content_label = QLabel("指令内容:")
        content_label.setStyleSheet("font-weight: bold; margin-top: 10px;")
        layout.addWidget(content_label)
        
        self.content_input = QTextEdit()
        self.content_input.setPlaceholderText("请输入指令的具体内容...\n\n例如：\n请分析用户的需求并提供解决方案\n注意事项：\n1. 分析要全面\n2. 方案要可行\n3. 考虑用户体验")
        self.content_input.setMinimumHeight(200)
        layout.addWidget(self.content_input)
        
        # 按钮区域
        button_layout = QHBoxLayout()
        button_layout.addStretch()
        
        # 取消按钮
        cancel_button = QPushButton("取消")
        cancel_button.setMinimumSize(80, 35)
        cancel_button.clicked.connect(self.reject)
        button_layout.addWidget(cancel_button)
        
        # 确定按钮
        self.ok_button = QPushButton("创建指令")
        self.ok_button.setMinimumSize(80, 35)
        self.ok_button.clicked.connect(self._save_command)
        self.ok_button.setDefault(True)
        button_layout.addWidget(self.ok_button)
        
        layout.addLayout(button_layout)
    
    def _apply_styles(self):
        """应用样式"""
        self.setStyleSheet("""
            QDialog {
                background-color: #2b2b2b;
                color: white;
            }
            QLabel {
                color: white;
                font-size: 12px;
            }
            QLineEdit {
                background-color: #404040;
                border: 1px solid #555;
                border-radius: 4px;
                padding: 8px;
                color: white;
                font-size: 12px;
            }
            QLineEdit:focus {
                border-color: #2196F3;
            }
            QTextEdit {
                background-color: #404040;
                border: 1px solid #555;
                border-radius: 4px;
                padding: 8px;
                color: white;
                font-size: 12px;
            }
            QTextEdit:focus {
                border-color: #2196F3;
            }
            QPushButton {
                background-color: #666666;
                color: white;
                border: none;
                padding: 8px 16px;
                border-radius: 4px;
                font-size: 12px;
            }
            QPushButton:hover {
                background-color: #777777;
            }
            QPushButton:pressed {
                background-color: #555555;
            }
            QPushButton:disabled {
                background-color: #444444;
                color: #888888;
            }
            QPushButton#create_button {
                background-color: #4CAF50;
                color: white;
            }
            QPushButton#create_button:hover {
                background-color: #45a049;
                color: white;
            }
            QPushButton#create_button:pressed {
                background-color: #3d8b40;
                color: white;
            }
        """)
        
        # 设置创建按钮的特殊样式
        self.ok_button.setObjectName("create_button")
    
    def _update_button_state(self):
        """更新按钮状态"""
        title = self.title_input.text().strip()
        content = self.content_input.toPlainText().strip()
        
        # 只有标题和内容都不为空时才启用按钮
        self.ok_button.setEnabled(bool(title and content))
    
    def _save_command(self):
        """保存新指令"""
        title = self.title_input.text().strip()
        content = self.content_input.toPlainText().strip()
        
        # 记录开始保存
        if DEBUG_LOG_AVAILABLE:
            logger = get_debug_logger()
            logger.log(f"开始保存指令: 标题='{title}', 内容长度={len(content)}", "SAVE")
        
        # 验证输入
        if not title:
            if DEBUG_LOG_AVAILABLE:
                logger = get_debug_logger()
                logger.log_error("指令保存", "标题为空")
            QMessageBox.warning(self, "输入错误", "请输入指令标题")
            return
        
        if not content:
            if DEBUG_LOG_AVAILABLE:
                logger = get_debug_logger()
                logger.log_error("指令保存", "内容为空")
            QMessageBox.warning(self, "输入错误", "请输入指令内容")
            return
        
        # 检查文件名是否合法
        if not self._is_valid_filename(title):
            if DEBUG_LOG_AVAILABLE:
                logger = get_debug_logger()
                logger.log_error("指令保存", f"文件名非法: '{title}'")
            QMessageBox.warning(self, "文件名错误", 
                              "文件名包含非法字符，请使用字母、数字、下划线或中文")
            return
        
        try:
            # 根据选择的类型确定保存目录
            # 只支持项目指令
            if True:  # 始终保存为项目指令
                # 项目指令：使用路径配置
                if not self.path_config:
                    QMessageBox.critical(self, "配置错误", "路径配置不可用，无法保存项目指令")
                    return
                prompts_dir = self.path_config.ensure_project_commands_dir(self.project_path)
                if DEBUG_LOG_AVAILABLE:
                    logger.log(f"使用路径配置保存项目指令: {prompts_dir}", "SAVE")
                path_type = "项目"
            else:
                # 私有指令：保存到与脚本同目录的prompts/
                if self.path_config:
                    prompts_dir = self.path_config.ensure_personal_commands_dir()
                    if DEBUG_LOG_AVAILABLE:
                        logger.log(f"使用路径配置保存个人指令: {prompts_dir}", "SAVE")
                else:
                    # 降级处理
                    prompts_dir = os.path.join(self.project_path, "prompts")
                    os.makedirs(prompts_dir, exist_ok=True)
                    if DEBUG_LOG_AVAILABLE:
                        logger.log(f"使用降级路径保存个人指令: {prompts_dir}", "SAVE")
                path_type = "私有"
            
            # 生成文件路径
            filename = f"{title}.md"
            file_path = os.path.join(prompts_dir, filename)
            
            if DEBUG_LOG_AVAILABLE:
                logger = get_debug_logger()
                logger.log(f"生成文件路径: {file_path}", "SAVE")
            
            # 检查文件是否已存在
            if os.path.exists(file_path):
                if DEBUG_LOG_AVAILABLE:
                    logger.log(f"文件已存在，询问是否覆盖: {file_path}", "SAVE")
                reply = QMessageBox.question(
                    self, "文件已存在", 
                    f"指令文件 '{filename}' 已存在，是否覆盖？",
                    QMessageBox.Yes | QMessageBox.No,
                    QMessageBox.No
                )
                if reply == QMessageBox.No:
                    if DEBUG_LOG_AVAILABLE:
                        logger.log("用户选择不覆盖，取消保存", "SAVE")
                    return
            
            # 创建文件内容
            file_content = self._generate_file_content(content)
            if DEBUG_LOG_AVAILABLE:
                logger.log(f"生成文件内容，长度: {len(file_content)}", "SAVE")
            
            # 写入文件
            with open(file_path, 'w', encoding='utf-8') as f:
                f.write(file_content)
            
            # 记录保存成功
            if DEBUG_LOG_AVAILABLE:
                logger.log_save_operation(f"{path_type}指令", file_path, True)
            
            # 先关闭对话框，确保界面刷新
            if DEBUG_LOG_AVAILABLE:
                logger.log("准备关闭对话框并发出变更信号", "SAVE")
            self.accept()  # 先关闭对话框，触发刷新
            
            # 然后显示成功消息（即使失败也不影响功能）
            try:
                try:
                    relative_path = os.path.relpath(file_path)
                except ValueError:
                    relative_path = file_path
                
                QMessageBox.information(
                    self, "创建成功", 
                    f"{path_type}指令文件已创建: {filename}\n位置: {relative_path}"
                )
            except Exception as msg_error:
                if DEBUG_LOG_AVAILABLE:
                    logger.log_error("消息框显示", str(msg_error))
            
        except Exception as e:
            if DEBUG_LOG_AVAILABLE:
                logger = get_debug_logger()
                logger.log_save_operation("指令", file_path if 'file_path' in locals() else 'unknown', False, str(e))
            QMessageBox.critical(
                self, "创建失败", 
                f"创建指令文件时发生错误:\n{str(e)}"
            )
    
    def _is_valid_filename(self, filename: str) -> bool:
        """检查文件名是否合法"""
        # 禁止的字符
        invalid_chars = '<>:"/\\|?*'
        for char in invalid_chars:
            if char in filename:
                return False
        
        # 禁止的文件名
        invalid_names = [
            'CON', 'PRN', 'AUX', 'NUL',
            'COM1', 'COM2', 'COM3', 'COM4', 'COM5', 'COM6', 'COM7', 'COM8', 'COM9',
            'LPT1', 'LPT2', 'LPT3', 'LPT4', 'LPT5', 'LPT6', 'LPT7', 'LPT8', 'LPT9'
        ]
        if filename.upper() in invalid_names:
            return False
        
        # 不能为空或只有空格
        if not filename.strip():
            return False
        
        return True
    
    def _generate_file_content(self, content: str) -> str:
        """生成.md文件内容"""
        # 从内容中提取前50个字符作为描述
        description = content[:50].replace('\n', ' ').strip()
        if len(content) > 50:
            description += "..."
        
        # 生成YAML前置内容
        yaml_content = f"""---
description: {description}
globs:
alwaysApply: false
---
{content}
"""
        return yaml_content


class EditCommandDialog(QDialog):
    """编辑指令对话框"""
    
    def __init__(self, project_path: str, command_data: Dict[str, Any], parent=None):
        super().__init__(parent)
        self.project_path = project_path
        self.command_data = command_data
        self.original_file_path = command_data.get('full_path', '')
        
        # 获取路径配置实例
        if PATH_CONFIG_AVAILABLE:
            self.path_config = get_path_config()
        else:
            self.path_config = None
        
        self.setWindowTitle("编辑指令")
        self.setModal(True)
        self.resize(500, 450)
        
        self._create_ui()
        self._apply_styles()
        self._load_command_data()
        
        # 连接信号
        self.title_input.textChanged.connect(self._update_button_state)
        self.content_input.textChanged.connect(self._update_button_state)
        
        # 设置初始状态
        self._update_button_state()
    
    def _create_ui(self):
        """创建对话框UI"""
        layout = QVBoxLayout(self)
        layout.setSpacing(15)
        layout.setContentsMargins(20, 20, 20, 20)
        
        # 标题
        title_label = QLabel("编辑自定义指令")
        title_label.setAlignment(Qt.AlignCenter)
        title_font = QFont()
        title_font.setPointSize(14)
        title_font.setBold(True)
        title_label.setFont(title_font)
        layout.addWidget(title_label)
        
        # 表单区域
        form_layout = QFormLayout()
        form_layout.setSpacing(10)
        
        # 指令类型选择（第一行）
        type_widget = QWidget()
        type_layout = QHBoxLayout(type_widget)
        type_layout.setContentsMargins(0, 0, 0, 0)
        self.type_button_group = QButtonGroup()
        
        # 项目指令选项
        self.project_radio = QRadioButton("项目指令")
        display_path = self.path_config.get_project_commands_display_path() if self.path_config else ".cursor/rules/"
        self.project_radio.setToolTip(f"保存到 {display_path} 目录，仅当前项目可用")
        self.type_button_group.addButton(self.project_radio, 0)
        type_layout.addWidget(self.project_radio)
        
        # 私有指令选项
        self.private_radio = QRadioButton("私有指令")
        self.private_radio.setToolTip("保存到 prompts/ 目录，个人全局可用")
        self.type_button_group.addButton(self.private_radio, 1)
        type_layout.addWidget(self.private_radio)
        
        type_layout.addStretch()  # 推送按钮到左侧
        form_layout.addRow("指令类型:", type_widget)
        
        # 指令标题输入
        self.title_input = QLineEdit()
        self.title_input.setPlaceholderText("请输入指令标题（将作为文件名）")
        self.title_input.setMinimumHeight(35)
        form_layout.addRow("指令标题:", self.title_input)
        
        layout.addLayout(form_layout)
        
        # 指令内容输入
        content_label = QLabel("指令内容:")
        content_label.setStyleSheet("font-weight: bold; margin-top: 10px;")
        layout.addWidget(content_label)
        
        self.content_input = QTextEdit()
        self.content_input.setPlaceholderText("请输入指令的具体内容...")
        self.content_input.setMinimumHeight(200)
        layout.addWidget(self.content_input)
        
        # 按钮区域
        button_layout = QHBoxLayout()
        button_layout.addStretch()

        # 删除按钮已移除 - 用户需直接删除 .md 文件

        # 取消按钮
        cancel_button = QPushButton("取消")
        cancel_button.setMinimumSize(80, 35)
        cancel_button.clicked.connect(self.reject)
        button_layout.addWidget(cancel_button)

        # 保存按钮
        self.save_button = QPushButton("💾 保存修改")
        self.save_button.setMinimumSize(100, 35)
        self.save_button.clicked.connect(self._save_command)
        self.save_button.setDefault(True)
        button_layout.addWidget(self.save_button)

        layout.addLayout(button_layout)
    
    def _apply_styles(self):
        """应用样式"""
        self.setStyleSheet("""
            QDialog {
                background-color: #2b2b2b;
                color: white;
            }
            QLabel {
                color: white;
                font-size: 12px;
            }
            QLineEdit {
                background-color: #404040;
                border: 1px solid #555;
                border-radius: 4px;
                padding: 8px;
                color: white;
                font-size: 12px;
            }
            QLineEdit:focus {
                border-color: #2196F3;
            }
            QTextEdit {
                background-color: #404040;
                border: 1px solid #555;
                border-radius: 4px;
                padding: 8px;
                color: white;
                font-size: 12px;
            }
            QTextEdit:focus {
                border-color: #2196F3;
            }
            QPushButton {
                background-color: #666666;
                color: white;
                border: none;
                padding: 8px 16px;
                border-radius: 4px;
                font-size: 12px;
            }
            QPushButton:hover {
                background-color: #777777;
            }
            QPushButton:pressed {
                background-color: #555555;
            }
            QPushButton:disabled {
                background-color: #444444;
                color: #888888;
            }
            QPushButton#create_button {
                background-color: #4CAF50;
                color: white;
            }
            QPushButton#create_button:hover {
                background-color: #45a049;
                color: white;
            }
            QPushButton#create_button:pressed {
                background-color: #3d8b40;
                color: white;
            }
        """)
        
        # 设置保存按钮的特殊样式
        self.save_button.setObjectName("create_button")
    
    def _load_command_data(self):
        """加载现有指令数据"""
        try:
            # 设置标题
            title = self.command_data.get('title', '')
            # 移除.md扩展名（如果存在）
            if title.endswith('.md'):
                title = title[:-4]
            self.title_input.setText(title)
            
            # 设置指令类型（根据路径判断）
            path_type = self.command_data.get('path_type', '')
            # 始终为项目指令（已移除私有指令）
            
            # 加载文件内容
            if self.original_file_path and os.path.exists(self.original_file_path):
                with open(self.original_file_path, 'r', encoding='utf-8') as f:
                    content = f.read()
                
                # 解析YAML前置内容
                if content.startswith('---'):
                    # 找到第二个---的位置
                    end_yaml = content.find('---', 3)
                    if end_yaml != -1:
                        # 提取实际内容（去掉YAML前置部分）
                        actual_content = content[end_yaml + 3:].strip()
                        self.content_input.setPlainText(actual_content)
                    else:
                        # 如果格式不正确，显示整个文件内容
                        self.content_input.setPlainText(content)
                else:
                    # 如果没有YAML前置，显示整个文件内容
                    self.content_input.setPlainText(content)
            
        except Exception as e:
            QMessageBox.warning(
                self, "加载失败", 
                f"加载指令文件时发生错误:\n{str(e)}"
            )
    
    def _update_button_state(self):
        """更新按钮状态"""
        title = self.title_input.text().strip()
        content = self.content_input.toPlainText().strip()
        
        # 只有标题和内容都不为空时才启用保存按钮
        self.save_button.setEnabled(bool(title and content))
    
    def _save_command(self):
        """保存指令修改"""
        title = self.title_input.text().strip()
        content = self.content_input.toPlainText().strip()
        
        # 验证输入
        if not title:
            QMessageBox.warning(self, "输入错误", "请输入指令标题")
            return
        
        if not content:
            QMessageBox.warning(self, "输入错误", "请输入指令内容")
            return
        
        # 检查文件名是否合法
        if not self._is_valid_filename(title):
            QMessageBox.warning(self, "文件名错误", 
                              "文件名包含非法字符，请使用字母、数字、下划线或中文")
            return
        
        try:
            # 根据选择的类型确定保存目录
            if self.project_radio.isChecked():
                # 项目指令：使用路径配置
                if not self.path_config:
                    QMessageBox.critical(self, "配置错误", "路径配置不可用，无法保存项目指令")
                    return
                prompts_dir = self.path_config.ensure_project_commands_dir(self.project_path)
                path_type = "项目"
            else:
                # 私有指令：保存到与脚本同目录的prompts/
                if self.path_config:
                    prompts_dir = self.path_config.ensure_personal_commands_dir()
                else:
                    # 降级处理
                    prompts_dir = os.path.join(self.project_path, "prompts")
                    os.makedirs(prompts_dir, exist_ok=True)
                path_type = "私有"
            
            # 生成新的文件路径
            filename = f"{title}.md"
            new_file_path = os.path.join(prompts_dir, filename)
            
            # 如果文件路径或名称改变了，需要处理原文件
            if new_file_path != self.original_file_path:
                # 检查新文件是否已存在
                if os.path.exists(new_file_path):
                    reply = QMessageBox.question(
                        self, "文件已存在", 
                        f"指令文件 '{filename}' 已存在，是否覆盖？",
                        QMessageBox.Yes | QMessageBox.No,
                        QMessageBox.No
                    )
                    if reply == QMessageBox.No:
                        return
                
                # 删除原文件（如果存在且不同于新文件）
                if os.path.exists(self.original_file_path):
                    os.remove(self.original_file_path)
            
            # 创建文件内容
            file_content = self._generate_file_content(content)
            
            # 写入文件
            with open(new_file_path, 'w', encoding='utf-8') as f:
                f.write(file_content)
            
            # 显示成功消息
            relative_path = os.path.relpath(new_file_path, os.getcwd()) if self.project_path else new_file_path
            QMessageBox.information(
                self, "保存成功", 
                f"{path_type}指令文件已保存: {filename}\n位置: {relative_path}"
            )
            
            # 关闭对话框
            self.accept()
            
        except Exception as e:
            QMessageBox.critical(
                self, "保存失败", 
                f"保存指令文件时发生错误:\n{str(e)}"
            )
    
    # 删除指令方法已移除 - 用户需直接删除 .md 文件

    def _is_valid_filename(self, filename: str) -> bool:
        """检查文件名是否合法"""
        # 禁止的字符
        invalid_chars = '<>:"/\\|?*'
        for char in invalid_chars:
            if char in filename:
                return False
        
        # 禁止的文件名
        invalid_names = [
            'CON', 'PRN', 'AUX', 'NUL',
            'COM1', 'COM2', 'COM3', 'COM4', 'COM5', 'COM6', 'COM7', 'COM8', 'COM9',
            'LPT1', 'LPT2', 'LPT3', 'LPT4', 'LPT5', 'LPT6', 'LPT7', 'LPT8', 'LPT9'
        ]
        if filename.upper() in invalid_names:
            return False
        
        # 不能为空或只有空格
        if not filename.strip():
            return False
        
        return True
    
    def _generate_file_content(self, content: str) -> str:
        """生成.md文件内容"""
        # 从内容中提取前50个字符作为描述
        description = content[:50].replace('\n', ' ').strip()
        if len(content) > 50:
            description += "..."
        
        # 生成YAML前置内容
        yaml_content = f"""---
description: {description}
globs:
alwaysApply: false
---
{content}
"""
        return yaml_content 